@@ -1,6 +1,8 @@
 import sys
 import typing
 
+GenericType = typing.TypeVar("GenericType")
+
 
 def check(check_ctxt, msgs, key, msgsrc, settings):
     ''' 
@@ -26,6 +28,14 @@ def dump_messages(do_messages, do_checks, settings):
     pass
 
 
+def dump_preset_messages(msgs, reports, settings):
+    ''' 
+
+    '''
+
+    pass
+
+
 def dump_py_messages(msgs, reports, addons, settings, addons_only):
     ''' 
 
