@@ -3,10 +3,12 @@ import typing
 import bpy.types
 import bmesh.types
 
-from . import utils
+from . import types
 from . import geometry
 from . import ops
-from . import types
+from . import utils
+
+GenericType = typing.TypeVar("GenericType")
 
 
 def from_edit_mesh(mesh: 'bpy.types.Mesh') -> 'bmesh.types.BMesh':
@@ -14,6 +16,7 @@ def from_edit_mesh(mesh: 'bpy.types.Mesh') -> 'bmesh.types.BMesh':
 
     :param mesh: The editmode mesh.
     :type mesh: 'bpy.types.Mesh'
+    :rtype: 'bmesh.types.BMesh'
     :return: the BMesh associated with this mesh.
     '''
 
@@ -25,6 +28,7 @@ def new(use_operators: bool = True) -> 'bmesh.types.BMesh':
 
     :param use_operators: bmesh.ops (uses some extra memory per vert/edge/face).
     :type use_operators: bool
+    :rtype: 'bmesh.types.BMesh'
     :return: Return a new, empty BMesh.
     '''
 
