@@ -195,7 +195,7 @@ class BMEdge:
         pass
 
     def normal_update(self):
-        ''' Update edges vertex normals.
+        ''' Update normals of all connected faces and the edge verts.
 
         '''
         pass
@@ -518,7 +518,7 @@ class BMFace:
         pass
 
     def normal_update(self):
-        ''' Update face's normal.
+        ''' Update face normal based on the positions of the face verts. This does not update the normals of face verts.
 
         '''
         pass
@@ -1134,7 +1134,7 @@ class BMVert:
         pass
 
     def normal_update(self):
-        ''' Update vertex normal.
+        ''' Update vertex normal. This does not update the normals of adjoining faces.
 
         '''
         pass
@@ -1326,7 +1326,7 @@ class BMesh:
         pass
 
     def normal_update(self):
-        ''' Update mesh normals.
+        ''' Update normals of mesh faces and verts.
 
         '''
         pass
