@@ -1,5 +1,27 @@
 import sys
 import typing
+
+GenericType = typing.TypeVar("GenericType")
+annotation_post = None
+''' on drawing an annotation (after)
+'''
+
+annotation_pre = None
+''' on drawing an annotation (before)
+'''
+
+composite_cancel = None
+''' on a compositing background job (cancel)
+'''
+
+composite_post = None
+''' on a compositing background job (after)
+'''
+
+composite_pre = None
+''' on a compositing background job (before)
+'''
+
 depsgraph_update_post = None
 ''' on depsgraph update (post)
 '''
@@ -32,6 +54,18 @@ load_pre = None
 ''' on loading a new blend file (before)
 '''
 
+object_bake_cancel = None
+''' on canceling a bake job; will be called in the main thread
+'''
+
+object_bake_complete = None
+''' on completing a bake job; will be called in the main thread
+'''
+
+object_bake_pre = None
+''' before starting a bake job
+'''
+
 persistent = None
 ''' Function decorator for callback functions not to be removed when loading new files
 '''
