@@ -136,14 +136,14 @@ def easing_type(override_context: typing.
                 execution_context: typing.Union[str, int] = None,
                 undo: bool = None,
                 *,
-                type: typing.Union[str, int] = 'AUTO'):
+                type: typing.Union[int, str] = 'AUTO'):
     ''' Set easing type for the F-Curve segments starting from the selected keyframes
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
     :type undo: bool
-    :param type: Type * AUTO Automatic Easing -- Easing type is chosen automatically based on what the type of interpolation used (e.g. Ease In for transitional types, and Ease Out for dynamic effects). * EASE_IN Ease In -- Only on the end closest to the next keyframe. * EASE_OUT Ease Out -- Only on the end closest to the first keyframe. * EASE_IN_OUT Ease In and Out -- Segment between both keyframes.
-    :type type: typing.Union[str, int]
+    :param type: Type
+    :type type: typing.Union[int, str]
     '''
 
     pass
@@ -186,14 +186,14 @@ def handle_type(override_context: typing.
                 execution_context: typing.Union[str, int] = None,
                 undo: bool = None,
                 *,
-                type: typing.Union[str, int] = 'FREE'):
+                type: typing.Union[int, str] = 'FREE'):
     ''' Set type of handle for selected keyframes
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
     :type undo: bool
-    :param type: Type * FREE Free -- Completely independent manually set handle. * ALIGNED Aligned -- Manually set handle with rotation locked together with its pair. * VECTOR Vector -- Automatic handles that create straight lines. * AUTO Automatic -- Automatic handles that create smooth curves. * AUTO_CLAMPED Auto Clamped -- Automatic handles that create smooth curves which only change direction at keyframes.
-    :type type: typing.Union[str, int]
+    :param type: Type
+    :type type: typing.Union[int, str]
     '''
 
     pass
@@ -204,14 +204,14 @@ def interpolation_type(override_context: typing.
                        execution_context: typing.Union[str, int] = None,
                        undo: bool = None,
                        *,
-                       type: typing.Union[str, int] = 'CONSTANT'):
+                       type: typing.Union[int, str] = 'CONSTANT'):
     ''' Set interpolation mode for the F-Curve segments starting from the selected keyframes
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
     :type undo: bool
-    :param type: Type * CONSTANT Constant -- No interpolation, value of A gets held until B is encountered. * LINEAR Linear -- Straight-line interpolation between A and B (i.e. no ease in/out). * BEZIER Bezier -- Smooth interpolation between A and B, with some control over curve shape. * SINE Sinusoidal -- Sinusoidal easing (weakest, almost linear but with a slight curvature). * QUAD Quadratic -- Quadratic easing. * CUBIC Cubic -- Cubic easing. * QUART Quartic -- Quartic easing. * QUINT Quintic -- Quintic easing. * EXPO Exponential -- Exponential easing (dramatic). * CIRC Circular -- Circular easing (strongest and most dynamic). * BACK Back -- Cubic easing with overshoot and settle. * BOUNCE Bounce -- Exponentially decaying parabolic bounce, like when objects collide. * ELASTIC Elastic -- Exponentially decaying sine wave, like an elastic band.
-    :type type: typing.Union[str, int]
+    :param type: Type
+    :type type: typing.Union[int, str]
     '''
 
     pass
@@ -240,14 +240,14 @@ def keyframe_type(override_context: typing.
                   execution_context: typing.Union[str, int] = None,
                   undo: bool = None,
                   *,
-                  type: typing.Union[str, int] = 'KEYFRAME'):
+                  type: typing.Union[int, str] = 'KEYFRAME'):
     ''' Set type of keyframe for the selected keyframes
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
     :type undo: bool
-    :param type: Type * KEYFRAME Keyframe -- Normal keyframe, e.g. for key poses. * BREAKDOWN Breakdown -- A breakdown pose, e.g. for transitions between key poses. * MOVING_HOLD Moving Hold -- A keyframe that is part of a moving hold. * EXTREME Extreme -- An "extreme" pose, or some other purpose as needed. * JITTER Jitter -- A filler or baked keyframe for keying on ones, or some other purpose as needed.
-    :type type: typing.Union[str, int]
+    :param type: Type
+    :type type: typing.Union[int, str]
     '''
 
     pass
@@ -332,18 +332,18 @@ def paste(override_context: typing.Union[typing.
           execution_context: typing.Union[str, int] = None,
           undo: bool = None,
           *,
-          offset: typing.Union[str, int] = 'START',
-          merge: typing.Union[str, int] = 'MIX',
+          offset: typing.Union[int, str] = 'START',
+          merge: typing.Union[int, str] = 'MIX',
           flipped: bool = False):
     ''' Paste keyframes from copy/paste buffer for the selected channels, starting on the current frame
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
     :type undo: bool
-    :param offset: Offset, Paste time offset of keys * START Frame Start -- Paste keys starting at current frame. * END Frame End -- Paste keys ending at current frame. * RELATIVE Frame Relative -- Paste keys relative to the current frame when copying. * NONE No Offset -- Paste keys from original time.
-    :type offset: typing.Union[str, int]
-    :param merge: Type, Method of merging pasted keys and existing * MIX Mix -- Overlay existing with new keys. * OVER_ALL Overwrite All -- Replace all keys. * OVER_RANGE Overwrite Range -- Overwrite keys in pasted range. * OVER_RANGE_ALL Overwrite Entire Range -- Overwrite keys in pasted range, using the range of all copied keys.
-    :type merge: typing.Union[str, int]
+    :param offset: Offset, Paste time offset of keys
+    :type offset: typing.Union[int, str]
+    :param merge: Type, Method of merging pasted keys and existing
+    :type merge: typing.Union[int, str]
     :param flipped: Flipped, Paste keyframes from mirrored bones if they exist
     :type flipped: bool
     '''
