@@ -1,24 +1,44 @@
 import sys
 import typing
+import bpy.types
+
+GenericType = typing.TypeVar("GenericType")
 
 
-def clear_filter():
+def clear_filter(override_context: typing.
+                 Union[typing.Dict, 'bpy.types.Context'] = None,
+                 execution_context: typing.Union[str, int] = None,
+                 undo: bool = None):
     ''' Clear the search filter
 
+    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
+    :type execution_context: typing.Union[str, int]
+    :type undo: bool
     '''
 
     pass
 
 
-def context_menu():
+def context_menu(override_context: typing.
+                 Union[typing.Dict, 'bpy.types.Context'] = None,
+                 execution_context: typing.Union[str, int] = None,
+                 undo: bool = None):
     ''' Display properties editor context_menu
 
+    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
+    :type execution_context: typing.Union[str, int]
+    :type undo: bool
     '''
 
     pass
 
 
-def directory_browse(directory: str = "",
+def directory_browse(override_context: typing.
+                     Union[typing.Dict, 'bpy.types.Context'] = None,
+                     execution_context: typing.Union[str, int] = None,
+                     undo: bool = None,
+                     *,
+                     directory: str = "",
                      hide_props_region: bool = True,
                      filter_blender: bool = False,
                      filter_backup: bool = False,
@@ -43,6 +63,9 @@ def directory_browse(directory: str = "",
                      sort_method: typing.Union[str, int] = ''):
     ''' Open a directory browser, hold Shift to open the file, Alt to browse containing directory
 
+    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
+    :type execution_context: typing.Union[str, int]
+    :type undo: bool
     :param directory: Directory, Directory of the file
     :type directory: str
     :param hide_props_region: Hide Operator Properties, Collapse the region displaying the operator settings
@@ -94,7 +117,12 @@ def directory_browse(directory: str = "",
     pass
 
 
-def file_browse(filepath: str = "",
+def file_browse(override_context: typing.
+                Union[typing.Dict, 'bpy.types.Context'] = None,
+                execution_context: typing.Union[str, int] = None,
+                undo: bool = None,
+                *,
+                filepath: str = "",
                 hide_props_region: bool = True,
                 filter_blender: bool = False,
                 filter_backup: bool = False,
@@ -119,6 +147,9 @@ def file_browse(filepath: str = "",
                 sort_method: typing.Union[str, int] = ''):
     ''' Open a file browser, hold Shift to open the file, Alt to browse containing directory
 
+    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
+    :type execution_context: typing.Union[str, int]
+    :type undo: bool
     :param filepath: File Path, Path to file
     :type filepath: str
     :param hide_props_region: Hide Operator Properties, Collapse the region displaying the operator settings
@@ -170,17 +201,29 @@ def file_browse(filepath: str = "",
     pass
 
 
-def start_filter():
+def start_filter(override_context: typing.
+                 Union[typing.Dict, 'bpy.types.Context'] = None,
+                 execution_context: typing.Union[str, int] = None,
+                 undo: bool = None):
     ''' Start entering filter text
 
+    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
+    :type execution_context: typing.Union[str, int]
+    :type undo: bool
     '''
 
     pass
 
 
-def toggle_pin():
+def toggle_pin(override_context: typing.
+               Union[typing.Dict, 'bpy.types.Context'] = None,
+               execution_context: typing.Union[str, int] = None,
+               undo: bool = None):
     ''' Keep the current data-block displayed
 
+    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
+    :type execution_context: typing.Union[str, int]
+    :type undo: bool
     '''
 
     pass
