@@ -126,7 +126,7 @@ def bundles_to_mesh(override_context: typing.
                     Union[typing.Dict, 'bpy.types.Context'] = None,
                     execution_context: typing.Union[str, int] = None,
                     undo: bool = None):
-    ''' Create vertex cloud using coordinates of reconstructed tracks :file: startup/bl_operators/clip.py\:282 <https://developer.blender.org/diffusion/B/browse/master/release/scripts/startup/bl_operators/clip.py$282> _
+    ''' Create vertex cloud using coordinates of reconstructed tracks :file: startup/bl_operators/clip.py\:280 <https://developer.blender.org/diffusion/B/browse/master/release/scripts/startup/bl_operators/clip.py$280> _
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
@@ -244,7 +244,7 @@ def constraint_to_fcurve(override_context: typing.
                          Union[typing.Dict, 'bpy.types.Context'] = None,
                          execution_context: typing.Union[str, int] = None,
                          undo: bool = None):
-    ''' Create F-Curves for object which will copy object's movement caused by this constraint :file: startup/bl_operators/clip.py\:520 <https://developer.blender.org/diffusion/B/browse/master/release/scripts/startup/bl_operators/clip.py$520> _
+    ''' Create F-Curves for object which will copy object's movement caused by this constraint :file: startup/bl_operators/clip.py\:518 <https://developer.blender.org/diffusion/B/browse/master/release/scripts/startup/bl_operators/clip.py$518> _
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
@@ -321,7 +321,7 @@ def delete_proxy(override_context: typing.
                  Union[typing.Dict, 'bpy.types.Context'] = None,
                  execution_context: typing.Union[str, int] = None,
                  undo: bool = None):
-    ''' Delete movie clip proxy files from the hard drive :file: startup/bl_operators/clip.py\:349 <https://developer.blender.org/diffusion/B/browse/master/release/scripts/startup/bl_operators/clip.py$349> _
+    ''' Delete movie clip proxy files from the hard drive :file: startup/bl_operators/clip.py\:347 <https://developer.blender.org/diffusion/B/browse/master/release/scripts/startup/bl_operators/clip.py$347> _
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
@@ -728,14 +728,29 @@ def mode_set(override_context: typing.Union[typing.
              execution_context: typing.Union[str, int] = None,
              undo: bool = None,
              *,
-             mode: typing.Union[str, int] = 'TRACKING'):
+             mode: typing.Union[int, str] = 'TRACKING'):
     ''' Set the clip interaction mode
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
     :type undo: bool
-    :param mode: Mode * TRACKING Tracking -- Show tracking and solving tools. * MASK Mask -- Show mask editing tools.
-    :type mode: typing.Union[str, int]
+    :param mode: Mode
+    :type mode: typing.Union[int, str]
+    '''
+
+    pass
+
+
+def new_image_from_plane_marker(
+        override_context: typing.Union[typing.
+                                       Dict, 'bpy.types.Context'] = None,
+        execution_context: typing.Union[str, int] = None,
+        undo: bool = None):
+    ''' Create new image from the content of the plane marker
+
+    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
+    :type execution_context: typing.Union[str, int]
+    :type undo: bool
     '''
 
     pass
@@ -1060,7 +1075,7 @@ def set_active_clip(override_context: typing.
                     Union[typing.Dict, 'bpy.types.Context'] = None,
                     execution_context: typing.Union[str, int] = None,
                     undo: bool = None):
-    ''' Undocumented, consider contributing <https://developer.blender.org/T51061> __. :file: startup/bl_operators/clip.py\:211 <https://developer.blender.org/diffusion/B/browse/master/release/scripts/startup/bl_operators/clip.py$211> _
+    ''' Undocumented, consider contributing <https://developer.blender.org/T51061> __. :file: startup/bl_operators/clip.py\:209 <https://developer.blender.org/diffusion/B/browse/master/release/scripts/startup/bl_operators/clip.py$209> _
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
@@ -1210,7 +1225,7 @@ def set_viewport_background(override_context: typing.
                             Union[typing.Dict, 'bpy.types.Context'] = None,
                             execution_context: typing.Union[str, int] = None,
                             undo: bool = None):
-    ''' Set current movie clip as a camera background in 3D Viewport (works only when a 3D Viewport is visible) :file: startup/bl_operators/clip.py\:410 <https://developer.blender.org/diffusion/B/browse/master/release/scripts/startup/bl_operators/clip.py$410> _
+    ''' Set current movie clip as a camera background in 3D Viewport (works only when a 3D Viewport is visible) :file: startup/bl_operators/clip.py\:408 <https://developer.blender.org/diffusion/B/browse/master/release/scripts/startup/bl_operators/clip.py$408> _
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
@@ -1224,7 +1239,7 @@ def setup_tracking_scene(override_context: typing.
                          Union[typing.Dict, 'bpy.types.Context'] = None,
                          execution_context: typing.Union[str, int] = None,
                          undo: bool = None):
-    ''' Prepare scene for compositing 3D objects into this footage :file: startup/bl_operators/clip.py\:972 <https://developer.blender.org/diffusion/B/browse/master/release/scripts/startup/bl_operators/clip.py$972> _
+    ''' Prepare scene for compositing 3D objects into this footage :file: startup/bl_operators/clip.py\:970 <https://developer.blender.org/diffusion/B/browse/master/release/scripts/startup/bl_operators/clip.py$970> _
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
@@ -1432,7 +1447,7 @@ def track_settings_as_default(override_context: typing.
                               Union[typing.Dict, 'bpy.types.Context'] = None,
                               execution_context: typing.Union[str, int] = None,
                               undo: bool = None):
-    ''' Copy tracking settings from active track to default settings :file: startup/bl_operators/clip.py\:1001 <https://developer.blender.org/diffusion/B/browse/master/release/scripts/startup/bl_operators/clip.py$1001> _
+    ''' Copy tracking settings from active track to default settings :file: startup/bl_operators/clip.py\:999 <https://developer.blender.org/diffusion/B/browse/master/release/scripts/startup/bl_operators/clip.py$999> _
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
@@ -1446,7 +1461,7 @@ def track_settings_to_track(override_context: typing.
                             Union[typing.Dict, 'bpy.types.Context'] = None,
                             execution_context: typing.Union[str, int] = None,
                             undo: bool = None):
-    ''' Copy tracking settings from active track to selected tracks :file: startup/bl_operators/clip.py\:1050 <https://developer.blender.org/diffusion/B/browse/master/release/scripts/startup/bl_operators/clip.py$1050> _
+    ''' Copy tracking settings from active track to selected tracks :file: startup/bl_operators/clip.py\:1048 <https://developer.blender.org/diffusion/B/browse/master/release/scripts/startup/bl_operators/clip.py$1048> _
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
@@ -1460,7 +1475,7 @@ def track_to_empty(override_context: typing.
                    Union[typing.Dict, 'bpy.types.Context'] = None,
                    execution_context: typing.Union[str, int] = None,
                    undo: bool = None):
-    ''' Create an Empty object which will be copying movement of active track :file: startup/bl_operators/clip.py\:258 <https://developer.blender.org/diffusion/B/browse/master/release/scripts/startup/bl_operators/clip.py$258> _
+    ''' Create an Empty object which will be copying movement of active track :file: startup/bl_operators/clip.py\:256 <https://developer.blender.org/diffusion/B/browse/master/release/scripts/startup/bl_operators/clip.py$256> _
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
@@ -1523,6 +1538,21 @@ def tracking_settings_preset_add(
     pass
 
 
+def update_image_from_plane_marker(
+        override_context: typing.Union[typing.
+                                       Dict, 'bpy.types.Context'] = None,
+        execution_context: typing.Union[str, int] = None,
+        undo: bool = None):
+    ''' Update current image used by plane marker from the content of the plane marker
+
+    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
+    :type execution_context: typing.Union[str, int]
+    :type undo: bool
+    '''
+
+    pass
+
+
 def view_all(override_context: typing.Union[typing.
                                             Dict, 'bpy.types.Context'] = None,
              execution_context: typing.Union[str, int] = None,
