@@ -109,7 +109,7 @@ def draw(override_context: typing.Union[typing.
          undo: bool = None,
          *,
          error_threshold: float = 0.0,
-         fit_method: typing.Union[str, int] = 'REFIT',
+         fit_method: typing.Union[int, str] = 'REFIT',
          corner_angle: float = 1.22173,
          use_cyclic: bool = True,
          stroke: bpy.types.
@@ -122,8 +122,8 @@ def draw(override_context: typing.Union[typing.
     :type undo: bool
     :param error_threshold: Error, Error distance threshold (in object units)
     :type error_threshold: float
-    :param fit_method: Fit Method * REFIT Refit -- Incrementally refit the curve (high quality). * SPLIT Split -- Split the curve until the tolerance is met (fast).
-    :type fit_method: typing.Union[str, int]
+    :param fit_method: Fit Method
+    :type fit_method: typing.Union[int, str]
     :param corner_angle: Corner Angle
     :type corner_angle: float
     :param use_cyclic: Cyclic
@@ -178,14 +178,14 @@ def extrude(override_context: typing.Union[typing.
             execution_context: typing.Union[str, int] = None,
             undo: bool = None,
             *,
-            mode: typing.Union[str, int] = 'TRANSLATION'):
+            mode: typing.Union[int, str] = 'TRANSLATION'):
     ''' Extrude selected control point(s)
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
     :type undo: bool
     :param mode: Mode
-    :type mode: typing.Union[str, int]
+    :type mode: typing.Union[int, str]
     '''
 
     pass
