@@ -70,14 +70,14 @@ def type_toggle(override_context: typing.
                 execution_context: typing.Union[str, int] = None,
                 undo: bool = None,
                 *,
-                type: typing.Union[str, int] = 'CANVAS'):
+                type: typing.Union[int, str] = 'CANVAS'):
     ''' Toggle whether given type is active or not
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
     :type undo: bool
     :param type: Type
-    :type type: typing.Union[str, int]
+    :type type: typing.Union[int, str]
     '''
 
     pass
