@@ -8,12 +8,12 @@ GenericType = typing.TypeVar("GenericType")
 def flush_edits(override_context: typing.
                 Union[typing.Dict, 'bpy.types.Context'] = None,
                 execution_context: typing.Union[str, int] = None,
-                undo: typing.Optional[bool] = None):
+                undo: bool = None):
     ''' Flush edit data from active editing modes
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     '''
 
     pass
@@ -22,12 +22,12 @@ def flush_edits(override_context: typing.
 def lib_id_fake_user_toggle(override_context: typing.
                             Union[typing.Dict, 'bpy.types.Context'] = None,
                             execution_context: typing.Union[str, int] = None,
-                            undo: typing.Optional[bool] = None):
+                            undo: bool = None):
     ''' Save this data-block even if it has no users
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     '''
 
     pass
@@ -36,12 +36,12 @@ def lib_id_fake_user_toggle(override_context: typing.
 def lib_id_generate_preview(override_context: typing.
                             Union[typing.Dict, 'bpy.types.Context'] = None,
                             execution_context: typing.Union[str, int] = None,
-                            undo: typing.Optional[bool] = None):
+                            undo: bool = None):
     ''' Create an automatic preview for the selected data-block
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     '''
 
     pass
@@ -51,12 +51,12 @@ def lib_id_generate_preview_from_object(
         override_context: typing.Union[typing.
                                        Dict, 'bpy.types.Context'] = None,
         execution_context: typing.Union[str, int] = None,
-        undo: typing.Optional[bool] = None):
+        undo: bool = None):
     ''' Create a preview for this asset by rendering the active object
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     '''
 
     pass
@@ -66,85 +66,85 @@ def lib_id_load_custom_preview(
         override_context: typing.Union[typing.
                                        Dict, 'bpy.types.Context'] = None,
         execution_context: typing.Union[str, int] = None,
-        undo: typing.Optional[bool] = None,
+        undo: bool = None,
         *,
-        filepath: typing.Union[str, typing.Any] = "",
-        hide_props_region: typing.Union[bool, typing.Any] = True,
-        filter_blender: typing.Union[bool, typing.Any] = False,
-        filter_backup: typing.Union[bool, typing.Any] = False,
-        filter_image: typing.Union[bool, typing.Any] = True,
-        filter_movie: typing.Union[bool, typing.Any] = False,
-        filter_python: typing.Union[bool, typing.Any] = False,
-        filter_font: typing.Union[bool, typing.Any] = False,
-        filter_sound: typing.Union[bool, typing.Any] = False,
-        filter_text: typing.Union[bool, typing.Any] = False,
-        filter_archive: typing.Union[bool, typing.Any] = False,
-        filter_btx: typing.Union[bool, typing.Any] = False,
-        filter_collada: typing.Union[bool, typing.Any] = False,
-        filter_alembic: typing.Union[bool, typing.Any] = False,
-        filter_usd: typing.Union[bool, typing.Any] = False,
-        filter_obj: typing.Union[bool, typing.Any] = False,
-        filter_volume: typing.Union[bool, typing.Any] = False,
-        filter_folder: typing.Union[bool, typing.Any] = True,
-        filter_blenlib: typing.Union[bool, typing.Any] = False,
-        filemode: typing.Optional[typing.Any] = 9,
-        show_multiview: typing.Union[bool, typing.Any] = False,
-        use_multiview: typing.Union[bool, typing.Any] = False,
-        display_type: typing.Optional[typing.Any] = 'DEFAULT',
-        sort_method: typing.Union[str, int, typing.Any] = ''):
+        filepath: str = "",
+        hide_props_region: bool = True,
+        filter_blender: bool = False,
+        filter_backup: bool = False,
+        filter_image: bool = True,
+        filter_movie: bool = False,
+        filter_python: bool = False,
+        filter_font: bool = False,
+        filter_sound: bool = False,
+        filter_text: bool = False,
+        filter_archive: bool = False,
+        filter_btx: bool = False,
+        filter_collada: bool = False,
+        filter_alembic: bool = False,
+        filter_usd: bool = False,
+        filter_obj: bool = False,
+        filter_volume: bool = False,
+        filter_folder: bool = True,
+        filter_blenlib: bool = False,
+        filemode: int = 9,
+        show_multiview: bool = False,
+        use_multiview: bool = False,
+        display_type: typing.Union[str, int] = 'DEFAULT',
+        sort_method: typing.Union[str, int] = ''):
     ''' Choose an image to help identify the data-block visually
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     :param filepath: File Path, Path to file
-    :type filepath: typing.Union[str, typing.Any]
+    :type filepath: str
     :param hide_props_region: Hide Operator Properties, Collapse the region displaying the operator settings
-    :type hide_props_region: typing.Union[bool, typing.Any]
+    :type hide_props_region: bool
     :param filter_blender: Filter .blend files
-    :type filter_blender: typing.Union[bool, typing.Any]
+    :type filter_blender: bool
     :param filter_backup: Filter .blend files
-    :type filter_backup: typing.Union[bool, typing.Any]
+    :type filter_backup: bool
     :param filter_image: Filter image files
-    :type filter_image: typing.Union[bool, typing.Any]
+    :type filter_image: bool
     :param filter_movie: Filter movie files
-    :type filter_movie: typing.Union[bool, typing.Any]
+    :type filter_movie: bool
     :param filter_python: Filter python files
-    :type filter_python: typing.Union[bool, typing.Any]
+    :type filter_python: bool
     :param filter_font: Filter font files
-    :type filter_font: typing.Union[bool, typing.Any]
+    :type filter_font: bool
     :param filter_sound: Filter sound files
-    :type filter_sound: typing.Union[bool, typing.Any]
+    :type filter_sound: bool
     :param filter_text: Filter text files
-    :type filter_text: typing.Union[bool, typing.Any]
+    :type filter_text: bool
     :param filter_archive: Filter archive files
-    :type filter_archive: typing.Union[bool, typing.Any]
+    :type filter_archive: bool
     :param filter_btx: Filter btx files
-    :type filter_btx: typing.Union[bool, typing.Any]
+    :type filter_btx: bool
     :param filter_collada: Filter COLLADA files
-    :type filter_collada: typing.Union[bool, typing.Any]
+    :type filter_collada: bool
     :param filter_alembic: Filter Alembic files
-    :type filter_alembic: typing.Union[bool, typing.Any]
+    :type filter_alembic: bool
     :param filter_usd: Filter USD files
-    :type filter_usd: typing.Union[bool, typing.Any]
+    :type filter_usd: bool
     :param filter_obj: Filter OBJ files
-    :type filter_obj: typing.Union[bool, typing.Any]
+    :type filter_obj: bool
     :param filter_volume: Filter OpenVDB volume files
-    :type filter_volume: typing.Union[bool, typing.Any]
+    :type filter_volume: bool
     :param filter_folder: Filter folders
-    :type filter_folder: typing.Union[bool, typing.Any]
+    :type filter_folder: bool
     :param filter_blenlib: Filter Blender IDs
-    :type filter_blenlib: typing.Union[bool, typing.Any]
+    :type filter_blenlib: bool
     :param filemode: File Browser Mode, The setting for the file browser mode to load a .blend file, a library or a special file
-    :type filemode: typing.Optional[typing.Any]
+    :type filemode: int
     :param show_multiview: Enable Multi-View
-    :type show_multiview: typing.Union[bool, typing.Any]
+    :type show_multiview: bool
     :param use_multiview: Use Multi-View
-    :type use_multiview: typing.Union[bool, typing.Any]
-    :param display_type: Display Type * ``DEFAULT`` Default -- Automatically determine display type for files. * ``LIST_VERTICAL`` Short List -- Display files as short list. * ``LIST_HORIZONTAL`` Long List -- Display files as a detailed list. * ``THUMBNAIL`` Thumbnails -- Display files as thumbnails.
-    :type display_type: typing.Optional[typing.Any]
+    :type use_multiview: bool
+    :param display_type: Display Type * DEFAULT Default -- Automatically determine display type for files. * LIST_VERTICAL Short List -- Display files as short list. * LIST_HORIZONTAL Long List -- Display files as a detailed list. * THUMBNAIL Thumbnails -- Display files as thumbnails.
+    :type display_type: typing.Union[str, int]
     :param sort_method: File sorting mode
-    :type sort_method: typing.Union[str, int, typing.Any]
+    :type sort_method: typing.Union[str, int]
     '''
 
     pass
@@ -154,12 +154,12 @@ def lib_id_override_editable_toggle(
         override_context: typing.Union[typing.
                                        Dict, 'bpy.types.Context'] = None,
         execution_context: typing.Union[str, int] = None,
-        undo: typing.Optional[bool] = None):
+        undo: bool = None):
     ''' Set if this library override data-block can be edited
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     '''
 
     pass
@@ -168,12 +168,12 @@ def lib_id_override_editable_toggle(
 def lib_id_unlink(override_context: typing.
                   Union[typing.Dict, 'bpy.types.Context'] = None,
                   execution_context: typing.Union[str, int] = None,
-                  undo: typing.Optional[bool] = None):
+                  undo: bool = None):
     ''' Remove a usage of a data-block, clearing the assignment
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     '''
 
     pass
@@ -182,12 +182,12 @@ def lib_id_unlink(override_context: typing.
 def redo(override_context: typing.Union[typing.
                                         Dict, 'bpy.types.Context'] = None,
          execution_context: typing.Union[str, int] = None,
-         undo: typing.Optional[bool] = None):
+         undo: bool = None):
     ''' Redo previous action
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     '''
 
     pass
@@ -196,12 +196,12 @@ def redo(override_context: typing.Union[typing.
 def undo(override_context: typing.Union[typing.
                                         Dict, 'bpy.types.Context'] = None,
          execution_context: typing.Union[str, int] = None,
-         undo: typing.Optional[bool] = None):
+         undo: bool = None):
     ''' Undo previous action
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     '''
 
     pass
@@ -210,36 +210,34 @@ def undo(override_context: typing.Union[typing.
 def undo_history(override_context: typing.
                  Union[typing.Dict, 'bpy.types.Context'] = None,
                  execution_context: typing.Union[str, int] = None,
-                 undo: typing.Optional[bool] = None,
+                 undo: bool = None,
                  *,
-                 item: typing.Optional[typing.Any] = 0):
+                 item: int = 0):
     ''' Redo specific action in history
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     :param item: Item
-    :type item: typing.Optional[typing.Any]
+    :type item: int
     '''
 
     pass
 
 
-def undo_push(
-        override_context: typing.Union[typing.
-                                       Dict, 'bpy.types.Context'] = None,
-        execution_context: typing.Union[str, int] = None,
-        undo: typing.Optional[bool] = None,
-        *,
-        message: typing.
-        Union[str, typing.Any] = "Add an undo step *function may be moved*"):
+def undo_push(override_context: typing.Union[typing.
+                                             Dict, 'bpy.types.Context'] = None,
+              execution_context: typing.Union[str, int] = None,
+              undo: bool = None,
+              *,
+              message: str = "Add an undo step *function may be moved*"):
     ''' Add an undo state (internal use only)
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     :param message: Undo Message
-    :type message: typing.Union[str, typing.Any]
+    :type message: str
     '''
 
     pass
@@ -248,12 +246,12 @@ def undo_push(
 def undo_redo(override_context: typing.Union[typing.
                                              Dict, 'bpy.types.Context'] = None,
               execution_context: typing.Union[str, int] = None,
-              undo: typing.Optional[bool] = None):
+              undo: bool = None):
     ''' Undo and redo previous action
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     '''
 
     pass
