@@ -163,6 +163,7 @@ def gltf(override_context: typing.Union[typing.
          export_draco_generic_quantization: int = 12,
          export_tangents: bool = False,
          export_materials: typing.Union[str, int] = 'EXPORT',
+         export_original_specular: bool = False,
          export_colors: bool = True,
          use_mesh_edges: bool = False,
          use_mesh_vertices: bool = False,
@@ -180,8 +181,10 @@ def gltf(override_context: typing.Union[typing.
          export_frame_step: int = 1,
          export_force_sampling: bool = True,
          export_nla_strips: bool = True,
+         export_nla_strips_merged_animation_name: str = "Animation",
          export_def_bones: bool = False,
          optimize_animation_size: bool = False,
+         export_anim_single_armature: bool = True,
          export_current_frame: bool = False,
          export_skins: bool = True,
          export_all_influences: bool = False,
@@ -189,7 +192,6 @@ def gltf(override_context: typing.Union[typing.
          export_morph_normal: bool = True,
          export_morph_tangent: bool = False,
          export_lights: bool = False,
-         export_displacement: bool = False,
          will_save_settings: bool = False,
          filter_glob: str = "*.glb;*.gltf"):
     ''' Export scene as glTF 2.0 file
@@ -235,6 +237,8 @@ def gltf(override_context: typing.Union[typing.
     :type export_tangents: bool
     :param export_materials: Materials, Export materials * EXPORT Export -- Export all materials used by included objects. * PLACEHOLDER Placeholder -- Do not export materials, but write multiple primitive groups per mesh, keeping material slot information. * NONE No export -- Do not export materials, and combine mesh primitive groups, losing material slot information.
     :type export_materials: typing.Union[str, int]
+    :param export_original_specular: Export original PBR Specular, Export original glTF PBR Specular, instead of Blender Principled Shader Specular
+    :type export_original_specular: bool
     :param export_colors: Vertex Colors, Export vertex colors with meshes
     :type export_colors: bool
     :param use_mesh_edges: Loose Edges, Export loose edges as lines, using the material from the first material slot
@@ -269,10 +273,14 @@ def gltf(override_context: typing.Union[typing.
     :type export_force_sampling: bool
     :param export_nla_strips: Group by NLA Track, When on, multiple actions become part of the same glTF animation if they're pushed onto NLA tracks with the same name. When off, all the currently assigned actions become one glTF animation
     :type export_nla_strips: bool
-    :param export_def_bones: Export Deformation Bones Only, Export Deformation bones only (and needed bones for hierarchy)
+    :param export_nla_strips_merged_animation_name: Merged Animation Name, Name of single glTF animation to be exported
+    :type export_nla_strips_merged_animation_name: str
+    :param export_def_bones: Export Deformation Bones Only, Export Deformation bones only
     :type export_def_bones: bool
     :param optimize_animation_size: Optimize Animation Size, Reduce exported file-size by removing duplicate keyframes(can cause problems with stepped animation)
     :type optimize_animation_size: bool
+    :param export_anim_single_armature: Export all Armature Actions, Export all actions, bound to a single armature. WARNING: Option does not support exports including multiple armatures
+    :type export_anim_single_armature: bool
     :param export_current_frame: Use Current Frame, Export the scene in the current animation frame
     :type export_current_frame: bool
     :param export_skins: Skinning, Export skinning (armature) data
@@ -287,8 +295,6 @@ def gltf(override_context: typing.Union[typing.
     :type export_morph_tangent: bool
     :param export_lights: Punctual Lights, Export directional, point, and spot lights. Uses "KHR_lights_punctual" glTF extension
     :type export_lights: bool
-    :param export_displacement: Displacement Textures (EXPERIMENTAL), EXPERIMENTAL: Export displacement textures. Uses incomplete "KHR_materials_displacement" glTF extension
-    :type export_displacement: bool
     :param will_save_settings: Remember Export Settings, Store glTF export settings in the Blender project
     :type will_save_settings: bool
     :param filter_glob: filter_glob
