@@ -135,6 +135,20 @@ def directory_new(override_context: typing.
     pass
 
 
+def edit_directory_path(override_context: typing.
+                        Union[typing.Dict, 'bpy.types.Context'] = None,
+                        execution_context: typing.Union[str, int] = None,
+                        undo: bool = None):
+    ''' Start editing directory field
+
+    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
+    :type execution_context: typing.Union[str, int]
+    :type undo: bool
+    '''
+
+    pass
+
+
 def execute(override_context: typing.Union[typing.
                                            Dict, 'bpy.types.Context'] = None,
             execution_context: typing.Union[str, int] = None,
