@@ -283,14 +283,14 @@ def duplicate(override_context: typing.Union[typing.
               execution_context: typing.Union[str, int] = None,
               undo: bool = None,
               *,
-              mode: typing.Union[str, int] = 'TRANSLATION'):
+              mode: typing.Union[int, str] = 'TRANSLATION'):
     ''' Make a copy of all selected keyframes
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
     :type undo: bool
     :param mode: Mode
-    :type mode: typing.Union[str, int]
+    :type mode: typing.Union[int, str]
     '''
 
     pass
@@ -323,14 +323,14 @@ def easing_type(override_context: typing.
                 execution_context: typing.Union[str, int] = None,
                 undo: bool = None,
                 *,
-                type: typing.Union[str, int] = 'AUTO'):
+                type: typing.Union[int, str] = 'AUTO'):
     ''' Set easing type for the F-Curve segments starting from the selected keyframes
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
     :type undo: bool
-    :param type: Type * AUTO Automatic Easing -- Easing type is chosen automatically based on what the type of interpolation used (e.g. Ease In for transitional types, and Ease Out for dynamic effects). * EASE_IN Ease In -- Only on the end closest to the next keyframe. * EASE_OUT Ease Out -- Only on the end closest to the first keyframe. * EASE_IN_OUT Ease In and Out -- Segment between both keyframes.
-    :type type: typing.Union[str, int]
+    :param type: Type
+    :type type: typing.Union[int, str]
     '''
 
     pass
@@ -397,15 +397,15 @@ def fmodifier_add(override_context: typing.
                   execution_context: typing.Union[str, int] = None,
                   undo: bool = None,
                   *,
-                  type: typing.Union[str, int] = 'NULL',
+                  type: typing.Union[int, str] = 'NULL',
                   only_active: bool = True):
     ''' Add F-Modifier to the active/selected F-Curves
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
     :type undo: bool
-    :param type: Type * NULL Invalid. * GENERATOR Generator -- Generate a curve using a factorized or expanded polynomial. * FNGENERATOR Built-In Function -- Generate a curve using standard math functions such as sin and cos. * ENVELOPE Envelope -- Reshape F-Curve values, e.g. change amplitude of movements. * CYCLES Cycles -- Cyclic extend/repeat keyframe sequence. * NOISE Noise -- Add pseudo-random noise on top of F-Curves. * LIMITS Limits -- Restrict maximum and minimum values of F-Curve. * STEPPED Stepped Interpolation -- Snap values to nearest grid step, e.g. for a stop-motion look.
-    :type type: typing.Union[str, int]
+    :param type: Type
+    :type type: typing.Union[int, str]
     :param only_active: Only Active, Only add F-Modifier to active F-Curve
     :type only_active: bool
     '''
@@ -495,14 +495,14 @@ def handle_type(override_context: typing.
                 execution_context: typing.Union[str, int] = None,
                 undo: bool = None,
                 *,
-                type: typing.Union[str, int] = 'FREE'):
+                type: typing.Union[int, str] = 'FREE'):
     ''' Set type of handle for selected keyframes
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
     :type undo: bool
-    :param type: Type * FREE Free -- Completely independent manually set handle. * ALIGNED Aligned -- Manually set handle with rotation locked together with its pair. * VECTOR Vector -- Automatic handles that create straight lines. * AUTO Automatic -- Automatic handles that create smooth curves. * AUTO_CLAMPED Auto Clamped -- Automatic handles that create smooth curves which only change direction at keyframes.
-    :type type: typing.Union[str, int]
+    :param type: Type
+    :type type: typing.Union[int, str]
     '''
 
     pass
@@ -531,14 +531,14 @@ def interpolation_type(override_context: typing.
                        execution_context: typing.Union[str, int] = None,
                        undo: bool = None,
                        *,
-                       type: typing.Union[str, int] = 'CONSTANT'):
+                       type: typing.Union[int, str] = 'CONSTANT'):
     ''' Set interpolation mode for the F-Curve segments starting from the selected keyframes
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
     :type undo: bool
-    :param type: Type * CONSTANT Constant -- No interpolation, value of A gets held until B is encountered. * LINEAR Linear -- Straight-line interpolation between A and B (i.e. no ease in/out). * BEZIER Bezier -- Smooth interpolation between A and B, with some control over curve shape. * SINE Sinusoidal -- Sinusoidal easing (weakest, almost linear but with a slight curvature). * QUAD Quadratic -- Quadratic easing. * CUBIC Cubic -- Cubic easing. * QUART Quartic -- Quartic easing. * QUINT Quintic -- Quintic easing. * EXPO Exponential -- Exponential easing (dramatic). * CIRC Circular -- Circular easing (strongest and most dynamic). * BACK Back -- Cubic easing with overshoot and settle. * BOUNCE Bounce -- Exponentially decaying parabolic bounce, like when objects collide. * ELASTIC Elastic -- Exponentially decaying sine wave, like an elastic band.
-    :type type: typing.Union[str, int]
+    :param type: Type
+    :type type: typing.Union[int, str]
     '''
 
     pass
@@ -585,18 +585,18 @@ def paste(override_context: typing.Union[typing.
           execution_context: typing.Union[str, int] = None,
           undo: bool = None,
           *,
-          offset: typing.Union[str, int] = 'START',
-          merge: typing.Union[str, int] = 'MIX',
+          offset: typing.Union[int, str] = 'START',
+          merge: typing.Union[int, str] = 'MIX',
           flipped: bool = False):
     ''' Paste keyframes from copy/paste buffer for the selected channels, starting on the current frame
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
     :type undo: bool
-    :param offset: Offset, Paste time offset of keys * START Frame Start -- Paste keys starting at current frame. * END Frame End -- Paste keys ending at current frame. * RELATIVE Frame Relative -- Paste keys relative to the current frame when copying. * NONE No Offset -- Paste keys from original time.
-    :type offset: typing.Union[str, int]
-    :param merge: Type, Method of merging pasted keys and existing * MIX Mix -- Overlay existing with new keys. * OVER_ALL Overwrite All -- Replace all keys. * OVER_RANGE Overwrite Range -- Overwrite keys in pasted range. * OVER_RANGE_ALL Overwrite Entire Range -- Overwrite keys in pasted range, using the range of all copied keys.
-    :type merge: typing.Union[str, int]
+    :param offset: Offset, Paste time offset of keys
+    :type offset: typing.Union[int, str]
+    :param merge: Type, Method of merging pasted keys and existing
+    :type merge: typing.Union[int, str]
     :param flipped: Flipped, Paste keyframes from mirrored bones if they exist
     :type flipped: bool
     '''
