@@ -8,16 +8,16 @@ GenericType = typing.TypeVar("GenericType")
 def flip(override_context: typing.Union[typing.
                                         Dict, 'bpy.types.Context'] = None,
          execution_context: typing.Union[str, int] = None,
-         undo: typing.Optional[bool] = None,
+         undo: bool = None,
          *,
-         axis: typing.Optional[typing.Any] = 'U'):
+         axis: typing.Union[str, int] = 'U'):
     ''' Mirror all control points without inverting the lattice deform
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     :param axis: Flip Axis, Coordinates along this axis get flipped
-    :type axis: typing.Optional[typing.Any]
+    :type axis: typing.Union[str, int]
     '''
 
     pass
@@ -26,12 +26,12 @@ def flip(override_context: typing.Union[typing.
 def make_regular(override_context: typing.
                  Union[typing.Dict, 'bpy.types.Context'] = None,
                  execution_context: typing.Union[str, int] = None,
-                 undo: typing.Optional[bool] = None):
+                 undo: bool = None):
     ''' Set UVW control points a uniform distance apart
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     '''
 
     pass
@@ -40,16 +40,16 @@ def make_regular(override_context: typing.
 def select_all(override_context: typing.
                Union[typing.Dict, 'bpy.types.Context'] = None,
                execution_context: typing.Union[str, int] = None,
-               undo: typing.Optional[bool] = None,
+               undo: bool = None,
                *,
-               action: typing.Optional[typing.Any] = 'TOGGLE'):
+               action: typing.Union[str, int] = 'TOGGLE'):
     ''' Change selection of all UVW control points
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
-    :param action: Action, Selection action to execute * ``TOGGLE`` Toggle -- Toggle selection for all elements. * ``SELECT`` Select -- Select all elements. * ``DESELECT`` Deselect -- Deselect all elements. * ``INVERT`` Invert -- Invert selection of all elements.
-    :type action: typing.Optional[typing.Any]
+    :type undo: bool
+    :param action: Action, Selection action to execute * TOGGLE Toggle -- Toggle selection for all elements. * SELECT Select -- Select all elements. * DESELECT Deselect -- Deselect all elements. * INVERT Invert -- Invert selection of all elements.
+    :type action: typing.Union[str, int]
     '''
 
     pass
@@ -58,12 +58,12 @@ def select_all(override_context: typing.
 def select_less(override_context: typing.
                 Union[typing.Dict, 'bpy.types.Context'] = None,
                 execution_context: typing.Union[str, int] = None,
-                undo: typing.Optional[bool] = None):
+                undo: bool = None):
     ''' Deselect vertices at the boundary of each selection region
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     '''
 
     pass
@@ -72,19 +72,19 @@ def select_less(override_context: typing.
 def select_mirror(override_context: typing.
                   Union[typing.Dict, 'bpy.types.Context'] = None,
                   execution_context: typing.Union[str, int] = None,
-                  undo: typing.Optional[bool] = None,
+                  undo: bool = None,
                   *,
-                  axis: typing.Optional[typing.Any] = {'X'},
-                  extend: typing.Union[bool, typing.Any] = False):
+                  axis: typing.Union[typing.Set[int], typing.Set[str]] = {'X'},
+                  extend: bool = False):
     ''' Select mirrored lattice points
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     :param axis: Axis
-    :type axis: typing.Optional[typing.Any]
+    :type axis: typing.Union[typing.Set[int], typing.Set[str]]
     :param extend: Extend, Extend the selection
-    :type extend: typing.Union[bool, typing.Any]
+    :type extend: bool
     '''
 
     pass
@@ -93,12 +93,12 @@ def select_mirror(override_context: typing.
 def select_more(override_context: typing.
                 Union[typing.Dict, 'bpy.types.Context'] = None,
                 execution_context: typing.Union[str, int] = None,
-                undo: typing.Optional[bool] = None):
+                undo: bool = None):
     ''' Select vertex directly linked to already selected ones
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     '''
 
     pass
@@ -107,22 +107,22 @@ def select_more(override_context: typing.
 def select_random(override_context: typing.
                   Union[typing.Dict, 'bpy.types.Context'] = None,
                   execution_context: typing.Union[str, int] = None,
-                  undo: typing.Optional[bool] = None,
+                  undo: bool = None,
                   *,
-                  ratio: typing.Optional[typing.Any] = 0.5,
-                  seed: typing.Optional[typing.Any] = 0,
-                  action: typing.Optional[typing.Any] = 'SELECT'):
+                  ratio: float = 0.5,
+                  seed: int = 0,
+                  action: typing.Union[str, int] = 'SELECT'):
     ''' Randomly select UVW control points
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     :param ratio: Ratio, Portion of items to select randomly
-    :type ratio: typing.Optional[typing.Any]
+    :type ratio: float
     :param seed: Random Seed, Seed for the random number generator
-    :type seed: typing.Optional[typing.Any]
-    :param action: Action, Selection action to execute * ``SELECT`` Select -- Select all elements. * ``DESELECT`` Deselect -- Deselect all elements.
-    :type action: typing.Optional[typing.Any]
+    :type seed: int
+    :param action: Action, Selection action to execute * SELECT Select -- Select all elements. * DESELECT Deselect -- Deselect all elements.
+    :type action: typing.Union[str, int]
     '''
 
     pass
@@ -131,16 +131,16 @@ def select_random(override_context: typing.
 def select_ungrouped(override_context: typing.
                      Union[typing.Dict, 'bpy.types.Context'] = None,
                      execution_context: typing.Union[str, int] = None,
-                     undo: typing.Optional[bool] = None,
+                     undo: bool = None,
                      *,
-                     extend: typing.Union[bool, typing.Any] = False):
+                     extend: bool = False):
     ''' Select vertices without a group
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     :param extend: Extend, Extend the selection
-    :type extend: typing.Union[bool, typing.Any]
+    :type extend: bool
     '''
 
     pass
