@@ -8,12 +8,12 @@ GenericType = typing.TypeVar("GenericType")
 def add(override_context: typing.Union[typing.
                                        Dict, 'bpy.types.Context'] = None,
         execution_context: typing.Union[str, int] = None,
-        undo: typing.Optional[bool] = None):
+        undo: bool = None):
     ''' Add a new time marker
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     '''
 
     pass
@@ -22,12 +22,12 @@ def add(override_context: typing.Union[typing.
 def camera_bind(override_context: typing.
                 Union[typing.Dict, 'bpy.types.Context'] = None,
                 execution_context: typing.Union[str, int] = None,
-                undo: typing.Optional[bool] = None):
+                undo: bool = None):
     ''' Bind the selected camera to a marker on the current frame
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     '''
 
     pass
@@ -36,12 +36,16 @@ def camera_bind(override_context: typing.
 def delete(override_context: typing.Union[typing.
                                           Dict, 'bpy.types.Context'] = None,
            execution_context: typing.Union[str, int] = None,
-           undo: typing.Optional[bool] = None):
+           undo: bool = None,
+           *,
+           confirm: bool = True):
     ''' Delete selected time marker(s)
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
+    :param confirm: Confirm, Prompt for confirmation
+    :type confirm: bool
     '''
 
     pass
@@ -50,16 +54,16 @@ def delete(override_context: typing.Union[typing.
 def duplicate(override_context: typing.Union[typing.
                                              Dict, 'bpy.types.Context'] = None,
               execution_context: typing.Union[str, int] = None,
-              undo: typing.Optional[bool] = None,
+              undo: bool = None,
               *,
-              frames: typing.Optional[typing.Any] = 0):
+              frames: int = 0):
     ''' Duplicate selected time marker(s)
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     :param frames: Frames
-    :type frames: typing.Optional[typing.Any]
+    :type frames: int
     '''
 
     pass
@@ -68,16 +72,16 @@ def duplicate(override_context: typing.Union[typing.
 def make_links_scene(override_context: typing.
                      Union[typing.Dict, 'bpy.types.Context'] = None,
                      execution_context: typing.Union[str, int] = None,
-                     undo: typing.Optional[bool] = None,
+                     undo: bool = None,
                      *,
-                     scene: typing.Union[str, int, typing.Any] = ''):
+                     scene: typing.Union[str, int] = ''):
     ''' Copy selected markers to another scene
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     :param scene: Scene
-    :type scene: typing.Union[str, int, typing.Any]
+    :type scene: typing.Union[str, int]
     '''
 
     pass
@@ -86,19 +90,19 @@ def make_links_scene(override_context: typing.
 def move(override_context: typing.Union[typing.
                                         Dict, 'bpy.types.Context'] = None,
          execution_context: typing.Union[str, int] = None,
-         undo: typing.Optional[bool] = None,
+         undo: bool = None,
          *,
-         frames: typing.Optional[typing.Any] = 0,
-         tweak: typing.Union[bool, typing.Any] = False):
+         frames: int = 0,
+         tweak: bool = False):
     ''' Move selected time marker(s)
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     :param frames: Frames
-    :type frames: typing.Optional[typing.Any]
+    :type frames: int
     :param tweak: Tweak, Operator has been activated using a click-drag event
-    :type tweak: typing.Union[bool, typing.Any]
+    :type tweak: bool
     '''
 
     pass
@@ -107,16 +111,16 @@ def move(override_context: typing.Union[typing.
 def rename(override_context: typing.Union[typing.
                                           Dict, 'bpy.types.Context'] = None,
            execution_context: typing.Union[str, int] = None,
-           undo: typing.Optional[bool] = None,
+           undo: bool = None,
            *,
-           name: typing.Union[str, typing.Any] = "RenamedMarker"):
+           name: str = "RenamedMarker"):
     ''' Rename first selected time marker
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     :param name: Name, New name for marker
-    :type name: typing.Union[str, typing.Any]
+    :type name: str
     '''
 
     pass
@@ -125,28 +129,28 @@ def rename(override_context: typing.Union[typing.
 def select(override_context: typing.Union[typing.
                                           Dict, 'bpy.types.Context'] = None,
            execution_context: typing.Union[str, int] = None,
-           undo: typing.Optional[bool] = None,
+           undo: bool = None,
            *,
-           wait_to_deselect_others: typing.Union[bool, typing.Any] = False,
-           mouse_x: typing.Optional[typing.Any] = 0,
-           mouse_y: typing.Optional[typing.Any] = 0,
-           extend: typing.Union[bool, typing.Any] = False,
-           camera: typing.Union[bool, typing.Any] = False):
+           wait_to_deselect_others: bool = False,
+           mouse_x: int = 0,
+           mouse_y: int = 0,
+           extend: bool = False,
+           camera: bool = False):
     ''' Select time marker(s)
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     :param wait_to_deselect_others: Wait to Deselect Others
-    :type wait_to_deselect_others: typing.Union[bool, typing.Any]
+    :type wait_to_deselect_others: bool
     :param mouse_x: Mouse X
-    :type mouse_x: typing.Optional[typing.Any]
+    :type mouse_x: int
     :param mouse_y: Mouse Y
-    :type mouse_y: typing.Optional[typing.Any]
+    :type mouse_y: int
     :param extend: Extend, Extend the selection
-    :type extend: typing.Union[bool, typing.Any]
+    :type extend: bool
     :param camera: Camera, Select the camera
-    :type camera: typing.Union[bool, typing.Any]
+    :type camera: bool
     '''
 
     pass
@@ -155,16 +159,16 @@ def select(override_context: typing.Union[typing.
 def select_all(override_context: typing.
                Union[typing.Dict, 'bpy.types.Context'] = None,
                execution_context: typing.Union[str, int] = None,
-               undo: typing.Optional[bool] = None,
+               undo: bool = None,
                *,
-               action: typing.Optional[typing.Any] = 'TOGGLE'):
+               action: typing.Union[str, int] = 'TOGGLE'):
     ''' Change selection of all time markers
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
-    :param action: Action, Selection action to execute * ``TOGGLE`` Toggle -- Toggle selection for all elements. * ``SELECT`` Select -- Select all elements. * ``DESELECT`` Deselect -- Deselect all elements. * ``INVERT`` Invert -- Invert selection of all elements.
-    :type action: typing.Optional[typing.Any]
+    :type undo: bool
+    :param action: Action, Selection action to execute * TOGGLE Toggle -- Toggle selection for all elements. * SELECT Select -- Select all elements. * DESELECT Deselect -- Deselect all elements. * INVERT Invert -- Invert selection of all elements.
+    :type action: typing.Union[str, int]
     '''
 
     pass
@@ -173,34 +177,34 @@ def select_all(override_context: typing.
 def select_box(override_context: typing.
                Union[typing.Dict, 'bpy.types.Context'] = None,
                execution_context: typing.Union[str, int] = None,
-               undo: typing.Optional[bool] = None,
+               undo: bool = None,
                *,
-               xmin: typing.Optional[typing.Any] = 0,
-               xmax: typing.Optional[typing.Any] = 0,
-               ymin: typing.Optional[typing.Any] = 0,
-               ymax: typing.Optional[typing.Any] = 0,
-               wait_for_input: typing.Union[bool, typing.Any] = True,
-               mode: typing.Optional[typing.Any] = 'SET',
-               tweak: typing.Union[bool, typing.Any] = False):
+               xmin: int = 0,
+               xmax: int = 0,
+               ymin: int = 0,
+               ymax: int = 0,
+               wait_for_input: bool = True,
+               mode: typing.Union[str, int] = 'SET',
+               tweak: bool = False):
     ''' Select all time markers using box selection
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     :param xmin: X Min
-    :type xmin: typing.Optional[typing.Any]
+    :type xmin: int
     :param xmax: X Max
-    :type xmax: typing.Optional[typing.Any]
+    :type xmax: int
     :param ymin: Y Min
-    :type ymin: typing.Optional[typing.Any]
+    :type ymin: int
     :param ymax: Y Max
-    :type ymax: typing.Optional[typing.Any]
+    :type ymax: int
     :param wait_for_input: Wait for Input
-    :type wait_for_input: typing.Union[bool, typing.Any]
-    :param mode: Mode * ``SET`` Set -- Set a new selection. * ``ADD`` Extend -- Extend existing selection. * ``SUB`` Subtract -- Subtract existing selection.
-    :type mode: typing.Optional[typing.Any]
+    :type wait_for_input: bool
+    :param mode: Mode * SET Set -- Set a new selection. * ADD Extend -- Extend existing selection. * SUB Subtract -- Subtract existing selection.
+    :type mode: typing.Union[str, int]
     :param tweak: Tweak, Operator has been activated using a click-drag event
-    :type tweak: typing.Union[bool, typing.Any]
+    :type tweak: bool
     '''
 
     pass
@@ -209,19 +213,19 @@ def select_box(override_context: typing.
 def select_leftright(override_context: typing.
                      Union[typing.Dict, 'bpy.types.Context'] = None,
                      execution_context: typing.Union[str, int] = None,
-                     undo: typing.Optional[bool] = None,
+                     undo: bool = None,
                      *,
-                     mode: typing.Optional[typing.Any] = 'LEFT',
-                     extend: typing.Union[bool, typing.Any] = False):
+                     mode: typing.Union[str, int] = 'LEFT',
+                     extend: bool = False):
     ''' Select markers on and left/right of the current frame
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     :param mode: mode, Mode
-    :type mode: typing.Optional[typing.Any]
+    :type mode: typing.Union[str, int]
     :param extend: extend, Extend
-    :type extend: typing.Union[bool, typing.Any]
+    :type extend: bool
     '''
 
     pass
