@@ -1,6 +1,7 @@
 import sys
 import typing
 import bpy.types
+import bpy.ops.transform
 
 GenericType = typing.TypeVar("GenericType")
 
@@ -218,8 +219,7 @@ def duplicate(override_context: typing.Union[typing.
               execution_context: typing.Union[str, int] = None,
               undo: bool = None,
               *,
-              linked: bool = False,
-              mode: typing.Union[str, int] = 'TRANSLATION'):
+              linked: bool = False):
     ''' Duplicate selected NLA-Strips, adding the new strips in new tracks above the originals
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
@@ -227,8 +227,50 @@ def duplicate(override_context: typing.Union[typing.
     :type undo: bool
     :param linked: Linked, When duplicating strips, assign new copies of the actions they use
     :type linked: bool
-    :param mode: Mode
-    :type mode: typing.Union[str, int]
+    '''
+
+    pass
+
+
+def duplicate_linked_move(
+        override_context: typing.Union[typing.
+                                       Dict, 'bpy.types.Context'] = None,
+        execution_context: typing.Union[str, int] = None,
+        undo: bool = None,
+        *,
+        NLA_OT_duplicate: 'duplicate' = None,
+        TRANSFORM_OT_translate: 'bpy.ops.transform.translate' = None):
+    ''' Duplicate selected strips and move them
+
+    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
+    :type execution_context: typing.Union[str, int]
+    :type undo: bool
+    :param NLA_OT_duplicate: Duplicate Strips, Duplicate selected NLA-Strips, adding the new strips in new tracks above the originals
+    :type NLA_OT_duplicate: 'duplicate'
+    :param TRANSFORM_OT_translate: Move, Move selected items
+    :type TRANSFORM_OT_translate: 'bpy.ops.transform.translate'
+    '''
+
+    pass
+
+
+def duplicate_move(
+        override_context: typing.Union[typing.
+                                       Dict, 'bpy.types.Context'] = None,
+        execution_context: typing.Union[str, int] = None,
+        undo: bool = None,
+        *,
+        NLA_OT_duplicate: 'duplicate' = None,
+        TRANSFORM_OT_translate: 'bpy.ops.transform.translate' = None):
+    ''' Duplicate selected strips and their Actions and move them
+
+    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
+    :type execution_context: typing.Union[str, int]
+    :type undo: bool
+    :param NLA_OT_duplicate: Duplicate Strips, Duplicate selected NLA-Strips, adding the new strips in new tracks above the originals
+    :type NLA_OT_duplicate: 'duplicate'
+    :param TRANSFORM_OT_translate: Move, Move selected items
+    :type TRANSFORM_OT_translate: 'bpy.ops.transform.translate'
     '''
 
     pass
@@ -239,15 +281,15 @@ def fmodifier_add(override_context: typing.
                   execution_context: typing.Union[str, int] = None,
                   undo: bool = None,
                   *,
-                  type: typing.Union[str, int] = 'NULL',
+                  type: typing.Union[int, str] = 'NULL',
                   only_active: bool = True):
     ''' Add F-Modifier to the active/selected NLA-Strips
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
     :type undo: bool
-    :param type: Type * NULL Invalid. * GENERATOR Generator -- Generate a curve using a factorized or expanded polynomial. * FNGENERATOR Built-In Function -- Generate a curve using standard math functions such as sin and cos. * ENVELOPE Envelope -- Reshape F-Curve values, e.g. change amplitude of movements. * CYCLES Cycles -- Cyclic extend/repeat keyframe sequence. * NOISE Noise -- Add pseudo-random noise on top of F-Curves. * LIMITS Limits -- Restrict maximum and minimum values of F-Curve. * STEPPED Stepped Interpolation -- Snap values to nearest grid step, e.g. for a stop-motion look.
-    :type type: typing.Union[str, int]
+    :param type: Type
+    :type type: typing.Union[int, str]
     :param only_active: Only Active, Only add a F-Modifier of the specified type to the active strip
     :type only_active: bool
     '''
