@@ -9,22 +9,47 @@ def cycles_integrator_preset_add(
         override_context: typing.Union[typing.
                                        Dict, 'bpy.types.Context'] = None,
         execution_context: typing.Union[str, int] = None,
-        undo: typing.Optional[bool] = None,
+        undo: bool = None,
         *,
-        name: typing.Union[str, typing.Any] = "",
-        remove_name: typing.Union[bool, typing.Any] = False,
-        remove_active: typing.Union[bool, typing.Any] = False):
+        name: str = "",
+        remove_name: bool = False,
+        remove_active: bool = False):
     ''' Add an Integrator Preset
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     :param name: Name, Name of the preset, used to make the path name
-    :type name: typing.Union[str, typing.Any]
+    :type name: str
     :param remove_name: remove_name
-    :type remove_name: typing.Union[bool, typing.Any]
+    :type remove_name: bool
     :param remove_active: remove_active
-    :type remove_active: typing.Union[bool, typing.Any]
+    :type remove_active: bool
+    '''
+
+    pass
+
+
+def cycles_performance_preset_add(
+        override_context: typing.Union[typing.
+                                       Dict, 'bpy.types.Context'] = None,
+        execution_context: typing.Union[str, int] = None,
+        undo: bool = None,
+        *,
+        name: str = "",
+        remove_name: bool = False,
+        remove_active: bool = False):
+    ''' Add an Performance Preset
+
+    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
+    :type execution_context: typing.Union[str, int]
+    :type undo: bool
+    :param name: Name, Name of the preset, used to make the path name
+    :type name: str
+    :param remove_name: remove_name
+    :type remove_name: bool
+    :param remove_active: remove_active
+    :type remove_active: bool
     '''
 
     pass
@@ -34,22 +59,22 @@ def cycles_sampling_preset_add(
         override_context: typing.Union[typing.
                                        Dict, 'bpy.types.Context'] = None,
         execution_context: typing.Union[str, int] = None,
-        undo: typing.Optional[bool] = None,
+        undo: bool = None,
         *,
-        name: typing.Union[str, typing.Any] = "",
-        remove_name: typing.Union[bool, typing.Any] = False,
-        remove_active: typing.Union[bool, typing.Any] = False):
+        name: str = "",
+        remove_name: bool = False,
+        remove_active: bool = False):
     ''' Add a Sampling Preset
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     :param name: Name, Name of the preset, used to make the path name
-    :type name: typing.Union[str, typing.Any]
+    :type name: str
     :param remove_name: remove_name
-    :type remove_name: typing.Union[bool, typing.Any]
+    :type remove_name: bool
     :param remove_active: remove_active
-    :type remove_active: typing.Union[bool, typing.Any]
+    :type remove_active: bool
     '''
 
     pass
@@ -59,22 +84,22 @@ def cycles_viewport_sampling_preset_add(
         override_context: typing.Union[typing.
                                        Dict, 'bpy.types.Context'] = None,
         execution_context: typing.Union[str, int] = None,
-        undo: typing.Optional[bool] = None,
+        undo: bool = None,
         *,
-        name: typing.Union[str, typing.Any] = "",
-        remove_name: typing.Union[bool, typing.Any] = False,
-        remove_active: typing.Union[bool, typing.Any] = False):
+        name: str = "",
+        remove_name: bool = False,
+        remove_active: bool = False):
     ''' Add a Viewport Sampling Preset
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     :param name: Name, Name of the preset, used to make the path name
-    :type name: typing.Union[str, typing.Any]
+    :type name: str
     :param remove_name: remove_name
-    :type remove_name: typing.Union[bool, typing.Any]
+    :type remove_name: bool
     :param remove_active: remove_active
-    :type remove_active: typing.Union[bool, typing.Any]
+    :type remove_active: bool
     '''
 
     pass
@@ -83,28 +108,28 @@ def cycles_viewport_sampling_preset_add(
 def opengl(override_context: typing.Union[typing.
                                           Dict, 'bpy.types.Context'] = None,
            execution_context: typing.Union[str, int] = None,
-           undo: typing.Optional[bool] = None,
+           undo: bool = None,
            *,
-           animation: typing.Union[bool, typing.Any] = False,
-           render_keyed_only: typing.Union[bool, typing.Any] = False,
-           sequencer: typing.Union[bool, typing.Any] = False,
-           write_still: typing.Union[bool, typing.Any] = False,
-           view_context: typing.Union[bool, typing.Any] = True):
+           animation: bool = False,
+           render_keyed_only: bool = False,
+           sequencer: bool = False,
+           write_still: bool = False,
+           view_context: bool = True):
     ''' Take a snapshot of the active viewport
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     :param animation: Animation, Render files from the animation range of this scene
-    :type animation: typing.Union[bool, typing.Any]
+    :type animation: bool
     :param render_keyed_only: Render Keyframes Only, Render only those frames where selected objects have a key in their animation data. Only used when rendering animation
-    :type render_keyed_only: typing.Union[bool, typing.Any]
+    :type render_keyed_only: bool
     :param sequencer: Sequencer, Render using the sequencer's OpenGL display
-    :type sequencer: typing.Union[bool, typing.Any]
+    :type sequencer: bool
     :param write_still: Write Image, Save rendered the image to the output path (used only when animation is disabled)
-    :type write_still: typing.Union[bool, typing.Any]
+    :type write_still: bool
     :param view_context: View Context, Use the current 3D view for rendering, else use scene settings
-    :type view_context: typing.Union[bool, typing.Any]
+    :type view_context: bool
     '''
 
     pass
@@ -113,12 +138,12 @@ def opengl(override_context: typing.Union[typing.
 def play_rendered_anim(override_context: typing.
                        Union[typing.Dict, 'bpy.types.Context'] = None,
                        execution_context: typing.Union[str, int] = None,
-                       undo: typing.Optional[bool] = None):
-    ''' Play back rendered frames/movies using an external player :file: `startup/bl_operators/screen_play_rendered_anim.py\:67 <https://developer.blender.org/diffusion/B/browse/master/release/scripts/startup/bl_operators/screen_play_rendered_anim.py$67>`_
+                       undo: bool = None):
+    ''' Play back rendered frames/movies using an external player :file: startup/bl_operators/screen_play_rendered_anim.py\:65 <https://developer.blender.org/diffusion/B/browse/master/release/scripts/startup/bl_operators/screen_play_rendered_anim.py$65> _
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     '''
 
     pass
@@ -127,22 +152,22 @@ def play_rendered_anim(override_context: typing.
 def preset_add(override_context: typing.
                Union[typing.Dict, 'bpy.types.Context'] = None,
                execution_context: typing.Union[str, int] = None,
-               undo: typing.Optional[bool] = None,
+               undo: bool = None,
                *,
-               name: typing.Union[str, typing.Any] = "",
-               remove_name: typing.Union[bool, typing.Any] = False,
-               remove_active: typing.Union[bool, typing.Any] = False):
+               name: str = "",
+               remove_name: bool = False,
+               remove_active: bool = False):
     ''' Add or remove a Render Preset
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     :param name: Name, Name of the preset, used to make the path name
-    :type name: typing.Union[str, typing.Any]
+    :type name: str
     :param remove_name: remove_name
-    :type remove_name: typing.Union[bool, typing.Any]
+    :type remove_name: bool
     :param remove_active: remove_active
-    :type remove_active: typing.Union[bool, typing.Any]
+    :type remove_active: bool
     '''
 
     pass
@@ -151,28 +176,28 @@ def preset_add(override_context: typing.
 def render(override_context: typing.Union[typing.
                                           Dict, 'bpy.types.Context'] = None,
            execution_context: typing.Union[str, int] = None,
-           undo: typing.Optional[bool] = None,
+           undo: bool = None,
            *,
-           animation: typing.Union[bool, typing.Any] = False,
-           write_still: typing.Union[bool, typing.Any] = False,
-           use_viewport: typing.Union[bool, typing.Any] = False,
-           layer: typing.Union[str, typing.Any] = "",
-           scene: typing.Union[str, typing.Any] = ""):
+           animation: bool = False,
+           write_still: bool = False,
+           use_viewport: bool = False,
+           layer: str = "",
+           scene: str = ""):
     ''' Render active scene
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     :param animation: Animation, Render files from the animation range of this scene
-    :type animation: typing.Union[bool, typing.Any]
+    :type animation: bool
     :param write_still: Write Image, Save rendered the image to the output path (used only when animation is disabled)
-    :type write_still: typing.Union[bool, typing.Any]
+    :type write_still: bool
     :param use_viewport: Use 3D Viewport, When inside a 3D viewport, use layers and camera of the viewport
-    :type use_viewport: typing.Union[bool, typing.Any]
+    :type use_viewport: bool
     :param layer: Render Layer, Single render layer to re-render (used only when animation is disabled)
-    :type layer: typing.Union[str, typing.Any]
+    :type layer: str
     :param scene: Scene, Scene to render, current scene if not specified
-    :type scene: typing.Union[str, typing.Any]
+    :type scene: str
     '''
 
     pass
@@ -181,16 +206,16 @@ def render(override_context: typing.Union[typing.
 def shutter_curve_preset(override_context: typing.
                          Union[typing.Dict, 'bpy.types.Context'] = None,
                          execution_context: typing.Union[str, int] = None,
-                         undo: typing.Optional[bool] = None,
+                         undo: bool = None,
                          *,
-                         shape: typing.Optional[typing.Any] = 'SMOOTH'):
+                         shape: typing.Union[str, int] = 'SMOOTH'):
     ''' Set shutter curve
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     :param shape: Mode
-    :type shape: typing.Optional[typing.Any]
+    :type shape: typing.Union[str, int]
     '''
 
     pass
@@ -199,12 +224,12 @@ def shutter_curve_preset(override_context: typing.
 def view_cancel(override_context: typing.
                 Union[typing.Dict, 'bpy.types.Context'] = None,
                 execution_context: typing.Union[str, int] = None,
-                undo: typing.Optional[bool] = None):
+                undo: bool = None):
     ''' Cancel show render view
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     '''
 
     pass
@@ -213,12 +238,12 @@ def view_cancel(override_context: typing.
 def view_show(override_context: typing.Union[typing.
                                              Dict, 'bpy.types.Context'] = None,
               execution_context: typing.Union[str, int] = None,
-              undo: typing.Optional[bool] = None):
+              undo: bool = None):
     ''' Toggle show render view
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     '''
 
     pass
