@@ -58,14 +58,14 @@ def constraint_add(override_context: typing.
                    execution_context: typing.Union[str, int] = None,
                    undo: bool = None,
                    *,
-                   type: typing.Union[str, int] = 'FIXED'):
+                   type: typing.Union[int, str] = 'FIXED'):
     ''' Add Rigid Body Constraint to active object
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
     :type undo: bool
-    :param type: Rigid Body Constraint Type * FIXED Fixed -- Glue rigid bodies together. * POINT Point -- Constrain rigid bodies to move around common pivot point. * HINGE Hinge -- Restrict rigid body rotation to one axis. * SLIDER Slider -- Restrict rigid body translation to one axis. * PISTON Piston -- Restrict rigid body translation and rotation to one axis. * GENERIC Generic -- Restrict translation and rotation to specified axes. * GENERIC_SPRING Generic Spring -- Restrict translation and rotation to specified axes with springs. * MOTOR Motor -- Drive rigid body around or along an axis.
-    :type type: typing.Union[str, int]
+    :param type: Rigid Body Constraint Type
+    :type type: typing.Union[int, str]
     '''
 
     pass
@@ -111,14 +111,14 @@ def object_add(override_context: typing.
                execution_context: typing.Union[str, int] = None,
                undo: bool = None,
                *,
-               type: typing.Union[str, int] = 'ACTIVE'):
+               type: typing.Union[int, str] = 'ACTIVE'):
     ''' Add active object as Rigid Body
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
     :type undo: bool
-    :param type: Rigid Body Type * ACTIVE Active -- Object is directly controlled by simulation results. * PASSIVE Passive -- Object is directly controlled by animation system.
-    :type type: typing.Union[str, int]
+    :param type: Rigid Body Type
+    :type type: typing.Union[int, str]
     '''
 
     pass
@@ -142,7 +142,7 @@ def object_settings_copy(override_context: typing.
                          Union[typing.Dict, 'bpy.types.Context'] = None,
                          execution_context: typing.Union[str, int] = None,
                          undo: bool = None):
-    ''' Copy Rigid Body settings from active object to selected :file: startup/bl_operators/rigidbody.py\:45 <https://developer.blender.org/diffusion/B/browse/master/release/scripts/startup/bl_operators/rigidbody.py$45> _
+    ''' Copy Rigid Body settings from active object to selected :file: startup/bl_operators/rigidbody.py\:43 <https://developer.blender.org/diffusion/B/browse/master/release/scripts/startup/bl_operators/rigidbody.py$43> _
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
@@ -157,14 +157,14 @@ def objects_add(override_context: typing.
                 execution_context: typing.Union[str, int] = None,
                 undo: bool = None,
                 *,
-                type: typing.Union[str, int] = 'ACTIVE'):
+                type: typing.Union[int, str] = 'ACTIVE'):
     ''' Add selected objects as Rigid Bodies
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
     :type undo: bool
-    :param type: Rigid Body Type * ACTIVE Active -- Object is directly controlled by simulation results. * PASSIVE Passive -- Object is directly controlled by animation system.
-    :type type: typing.Union[str, int]
+    :param type: Rigid Body Type
+    :type type: typing.Union[int, str]
     '''
 
     pass
@@ -189,14 +189,14 @@ def shape_change(override_context: typing.
                  execution_context: typing.Union[str, int] = None,
                  undo: bool = None,
                  *,
-                 type: typing.Union[str, int] = 'MESH'):
+                 type: typing.Union[int, str] = 'MESH'):
     ''' Change collision shapes for selected Rigid Body Objects
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
     :type undo: bool
-    :param type: Rigid Body Shape * BOX Box -- Box-like shapes (i.e. cubes), including planes (i.e. ground planes). * SPHERE Sphere. * CAPSULE Capsule. * CYLINDER Cylinder. * CONE Cone. * CONVEX_HULL Convex Hull -- A mesh-like surface encompassing (i.e. shrinkwrap over) all vertices (best results with fewer vertices). * MESH Mesh -- Mesh consisting of triangles only, allowing for more detailed interactions than convex hulls. * COMPOUND Compound Parent -- Combines all of its direct rigid body children into one rigid object.
-    :type type: typing.Union[str, int]
+    :param type: Rigid Body Shape
+    :type type: typing.Union[int, str]
     '''
 
     pass
