@@ -8,12 +8,12 @@ GenericType = typing.TypeVar("GenericType")
 def delete(override_context: typing.Union[typing.
                                           Dict, 'bpy.types.Context'] = None,
            execution_context: typing.Union[str, int] = None,
-           undo: typing.Optional[bool] = None):
+           undo: bool = None):
     ''' Delete active scene
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     '''
 
     pass
@@ -23,12 +23,12 @@ def freestyle_add_edge_marks_to_keying_set(
         override_context: typing.Union[typing.
                                        Dict, 'bpy.types.Context'] = None,
         execution_context: typing.Union[str, int] = None,
-        undo: typing.Optional[bool] = None):
-    ''' Add the data paths to the Freestyle Edge Mark property of selected edges to the active keying set :file: `startup/bl_operators/freestyle.py\:133 <https://developer.blender.org/diffusion/B/browse/master/release/scripts/startup/bl_operators/freestyle.py$133>`_
+        undo: bool = None):
+    ''' Add the data paths to the Freestyle Edge Mark property of selected edges to the active keying set :file: startup/bl_operators/freestyle.py\:131 <https://developer.blender.org/diffusion/B/browse/master/release/scripts/startup/bl_operators/freestyle.py$131> _
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     '''
 
     pass
@@ -38,12 +38,12 @@ def freestyle_add_face_marks_to_keying_set(
         override_context: typing.Union[typing.
                                        Dict, 'bpy.types.Context'] = None,
         execution_context: typing.Union[str, int] = None,
-        undo: typing.Optional[bool] = None):
-    ''' Add the data paths to the Freestyle Face Mark property of selected polygons to the active keying set :file: `startup/bl_operators/freestyle.py\:164 <https://developer.blender.org/diffusion/B/browse/master/release/scripts/startup/bl_operators/freestyle.py$164>`_
+        undo: bool = None):
+    ''' Add the data paths to the Freestyle Face Mark property of selected polygons to the active keying set :file: startup/bl_operators/freestyle.py\:162 <https://developer.blender.org/diffusion/B/browse/master/release/scripts/startup/bl_operators/freestyle.py$162> _
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     '''
 
     pass
@@ -53,16 +53,16 @@ def freestyle_alpha_modifier_add(
         override_context: typing.Union[typing.
                                        Dict, 'bpy.types.Context'] = None,
         execution_context: typing.Union[str, int] = None,
-        undo: typing.Optional[bool] = None,
+        undo: bool = None,
         *,
-        type: typing.Optional[typing.Any] = 'ALONG_STROKE'):
+        type: typing.Union[int, str] = 'ALONG_STROKE'):
     ''' Add an alpha transparency modifier to the line style associated with the active lineset
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     :param type: Type
-    :type type: typing.Optional[typing.Any]
+    :type type: typing.Union[int, str]
     '''
 
     pass
@@ -72,16 +72,16 @@ def freestyle_color_modifier_add(
         override_context: typing.Union[typing.
                                        Dict, 'bpy.types.Context'] = None,
         execution_context: typing.Union[str, int] = None,
-        undo: typing.Optional[bool] = None,
+        undo: bool = None,
         *,
-        type: typing.Optional[typing.Any] = 'ALONG_STROKE'):
+        type: typing.Union[int, str] = 'ALONG_STROKE'):
     ''' Add a line color modifier to the line style associated with the active lineset
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     :param type: Type
-    :type type: typing.Optional[typing.Any]
+    :type type: typing.Union[int, str]
     '''
 
     pass
@@ -91,19 +91,19 @@ def freestyle_fill_range_by_selection(
         override_context: typing.Union[typing.
                                        Dict, 'bpy.types.Context'] = None,
         execution_context: typing.Union[str, int] = None,
-        undo: typing.Optional[bool] = None,
+        undo: bool = None,
         *,
-        type: typing.Optional[typing.Any] = 'COLOR',
-        name: typing.Union[str, typing.Any] = ""):
+        type: typing.Union[str, int] = 'COLOR',
+        name: str = ""):
     ''' Fill the Range Min/Max entries by the min/max distance between selected mesh objects and the source object
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
-    :param type: Type, Type of the modifier to work on * ``COLOR`` Color -- Color modifier type. * ``ALPHA`` Alpha -- Alpha modifier type. * ``THICKNESS`` Thickness -- Thickness modifier type.
-    :type type: typing.Optional[typing.Any]
+    :type undo: bool
+    :param type: Type, Type of the modifier to work on * COLOR Color -- Color modifier type. * ALPHA Alpha -- Alpha modifier type. * THICKNESS Thickness -- Thickness modifier type.
+    :type type: typing.Union[str, int]
     :param name: Name, Name of the modifier to work on
-    :type name: typing.Union[str, typing.Any]
+    :type name: str
     '''
 
     pass
@@ -113,16 +113,16 @@ def freestyle_geometry_modifier_add(
         override_context: typing.Union[typing.
                                        Dict, 'bpy.types.Context'] = None,
         execution_context: typing.Union[str, int] = None,
-        undo: typing.Optional[bool] = None,
+        undo: bool = None,
         *,
-        type: typing.Optional[typing.Any] = '2D_OFFSET'):
+        type: typing.Union[int, str] = '2D_OFFSET'):
     ''' Add a stroke geometry modifier to the line style associated with the active lineset
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     :param type: Type
-    :type type: typing.Optional[typing.Any]
+    :type type: typing.Union[int, str]
     '''
 
     pass
@@ -131,12 +131,12 @@ def freestyle_geometry_modifier_add(
 def freestyle_lineset_add(override_context: typing.
                           Union[typing.Dict, 'bpy.types.Context'] = None,
                           execution_context: typing.Union[str, int] = None,
-                          undo: typing.Optional[bool] = None):
+                          undo: bool = None):
     ''' Add a line set into the list of line sets
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     '''
 
     pass
@@ -145,12 +145,12 @@ def freestyle_lineset_add(override_context: typing.
 def freestyle_lineset_copy(override_context: typing.
                            Union[typing.Dict, 'bpy.types.Context'] = None,
                            execution_context: typing.Union[str, int] = None,
-                           undo: typing.Optional[bool] = None):
+                           undo: bool = None):
     ''' Copy the active line set to a buffer
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     '''
 
     pass
@@ -159,16 +159,16 @@ def freestyle_lineset_copy(override_context: typing.
 def freestyle_lineset_move(override_context: typing.
                            Union[typing.Dict, 'bpy.types.Context'] = None,
                            execution_context: typing.Union[str, int] = None,
-                           undo: typing.Optional[bool] = None,
+                           undo: bool = None,
                            *,
-                           direction: typing.Optional[typing.Any] = 'UP'):
+                           direction: typing.Union[str, int] = 'UP'):
     ''' Change the position of the active line set within the list of line sets
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     :param direction: Direction, Direction to move the active line set towards
-    :type direction: typing.Optional[typing.Any]
+    :type direction: typing.Union[str, int]
     '''
 
     pass
@@ -177,12 +177,12 @@ def freestyle_lineset_move(override_context: typing.
 def freestyle_lineset_paste(override_context: typing.
                             Union[typing.Dict, 'bpy.types.Context'] = None,
                             execution_context: typing.Union[str, int] = None,
-                            undo: typing.Optional[bool] = None):
+                            undo: bool = None):
     ''' Paste the buffer content to the active line set
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     '''
 
     pass
@@ -191,12 +191,12 @@ def freestyle_lineset_paste(override_context: typing.
 def freestyle_lineset_remove(override_context: typing.
                              Union[typing.Dict, 'bpy.types.Context'] = None,
                              execution_context: typing.Union[str, int] = None,
-                             undo: typing.Optional[bool] = None):
+                             undo: bool = None):
     ''' Remove the active line set from the list of line sets
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     '''
 
     pass
@@ -205,12 +205,12 @@ def freestyle_lineset_remove(override_context: typing.
 def freestyle_linestyle_new(override_context: typing.
                             Union[typing.Dict, 'bpy.types.Context'] = None,
                             execution_context: typing.Union[str, int] = None,
-                            undo: typing.Optional[bool] = None):
+                            undo: bool = None):
     ''' Create a new line style, reusable by multiple line sets
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     '''
 
     pass
@@ -219,12 +219,12 @@ def freestyle_linestyle_new(override_context: typing.
 def freestyle_modifier_copy(override_context: typing.
                             Union[typing.Dict, 'bpy.types.Context'] = None,
                             execution_context: typing.Union[str, int] = None,
-                            undo: typing.Optional[bool] = None):
+                            undo: bool = None):
     ''' Duplicate the modifier within the list of modifiers
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     '''
 
     pass
@@ -233,16 +233,16 @@ def freestyle_modifier_copy(override_context: typing.
 def freestyle_modifier_move(override_context: typing.
                             Union[typing.Dict, 'bpy.types.Context'] = None,
                             execution_context: typing.Union[str, int] = None,
-                            undo: typing.Optional[bool] = None,
+                            undo: bool = None,
                             *,
-                            direction: typing.Optional[typing.Any] = 'UP'):
+                            direction: typing.Union[str, int] = 'UP'):
     ''' Move the modifier within the list of modifiers
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     :param direction: Direction, Direction to move the chosen modifier towards
-    :type direction: typing.Optional[typing.Any]
+    :type direction: typing.Union[str, int]
     '''
 
     pass
@@ -251,12 +251,12 @@ def freestyle_modifier_move(override_context: typing.
 def freestyle_modifier_remove(override_context: typing.
                               Union[typing.Dict, 'bpy.types.Context'] = None,
                               execution_context: typing.Union[str, int] = None,
-                              undo: typing.Optional[bool] = None):
+                              undo: bool = None):
     ''' Remove the modifier from the list of modifiers
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     '''
 
     pass
@@ -265,12 +265,12 @@ def freestyle_modifier_remove(override_context: typing.
 def freestyle_module_add(override_context: typing.
                          Union[typing.Dict, 'bpy.types.Context'] = None,
                          execution_context: typing.Union[str, int] = None,
-                         undo: typing.Optional[bool] = None):
+                         undo: bool = None):
     ''' Add a style module into the list of modules
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     '''
 
     pass
@@ -279,38 +279,37 @@ def freestyle_module_add(override_context: typing.
 def freestyle_module_move(override_context: typing.
                           Union[typing.Dict, 'bpy.types.Context'] = None,
                           execution_context: typing.Union[str, int] = None,
-                          undo: typing.Optional[bool] = None,
+                          undo: bool = None,
                           *,
-                          direction: typing.Optional[typing.Any] = 'UP'):
+                          direction: typing.Union[str, int] = 'UP'):
     ''' Change the position of the style module within in the list of style modules
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     :param direction: Direction, Direction to move the chosen style module towards
-    :type direction: typing.Optional[typing.Any]
+    :type direction: typing.Union[str, int]
     '''
 
     pass
 
 
-def freestyle_module_open(
-        override_context: typing.Union[typing.
-                                       Dict, 'bpy.types.Context'] = None,
-        execution_context: typing.Union[str, int] = None,
-        undo: typing.Optional[bool] = None,
-        *,
-        filepath: typing.Union[str, typing.Any] = "",
-        make_internal: typing.Union[bool, typing.Any] = True):
+def freestyle_module_open(override_context: typing.
+                          Union[typing.Dict, 'bpy.types.Context'] = None,
+                          execution_context: typing.Union[str, int] = None,
+                          undo: bool = None,
+                          *,
+                          filepath: str = "",
+                          make_internal: bool = True):
     ''' Open a style module file
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     :param filepath: filepath
-    :type filepath: typing.Union[str, typing.Any]
+    :type filepath: str
     :param make_internal: Make internal, Make module file internal after loading
-    :type make_internal: typing.Union[bool, typing.Any]
+    :type make_internal: bool
     '''
 
     pass
@@ -319,12 +318,12 @@ def freestyle_module_open(
 def freestyle_module_remove(override_context: typing.
                             Union[typing.Dict, 'bpy.types.Context'] = None,
                             execution_context: typing.Union[str, int] = None,
-                            undo: typing.Optional[bool] = None):
+                            undo: bool = None):
     ''' Remove the style module from the stack
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     '''
 
     pass
@@ -334,12 +333,12 @@ def freestyle_stroke_material_create(
         override_context: typing.Union[typing.
                                        Dict, 'bpy.types.Context'] = None,
         execution_context: typing.Union[str, int] = None,
-        undo: typing.Optional[bool] = None):
+        undo: bool = None):
     ''' Create Freestyle stroke material for testing
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     '''
 
     pass
@@ -349,41 +348,40 @@ def freestyle_thickness_modifier_add(
         override_context: typing.Union[typing.
                                        Dict, 'bpy.types.Context'] = None,
         execution_context: typing.Union[str, int] = None,
-        undo: typing.Optional[bool] = None,
+        undo: bool = None,
         *,
-        type: typing.Optional[typing.Any] = 'ALONG_STROKE'):
+        type: typing.Union[int, str] = 'ALONG_STROKE'):
     ''' Add a line thickness modifier to the line style associated with the active lineset
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     :param type: Type
-    :type type: typing.Optional[typing.Any]
+    :type type: typing.Union[int, str]
     '''
 
     pass
 
 
-def gpencil_brush_preset_add(
-        override_context: typing.Union[typing.
-                                       Dict, 'bpy.types.Context'] = None,
-        execution_context: typing.Union[str, int] = None,
-        undo: typing.Optional[bool] = None,
-        *,
-        name: typing.Union[str, typing.Any] = "",
-        remove_name: typing.Union[bool, typing.Any] = False,
-        remove_active: typing.Union[bool, typing.Any] = False):
+def gpencil_brush_preset_add(override_context: typing.
+                             Union[typing.Dict, 'bpy.types.Context'] = None,
+                             execution_context: typing.Union[str, int] = None,
+                             undo: bool = None,
+                             *,
+                             name: str = "",
+                             remove_name: bool = False,
+                             remove_active: bool = False):
     ''' Add or remove grease pencil brush preset
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     :param name: Name, Name of the preset, used to make the path name
-    :type name: typing.Union[str, typing.Any]
+    :type name: str
     :param remove_name: remove_name
-    :type remove_name: typing.Union[bool, typing.Any]
+    :type remove_name: bool
     :param remove_active: remove_active
-    :type remove_active: typing.Union[bool, typing.Any]
+    :type remove_active: bool
     '''
 
     pass
@@ -393,22 +391,22 @@ def gpencil_material_preset_add(
         override_context: typing.Union[typing.
                                        Dict, 'bpy.types.Context'] = None,
         execution_context: typing.Union[str, int] = None,
-        undo: typing.Optional[bool] = None,
+        undo: bool = None,
         *,
-        name: typing.Union[str, typing.Any] = "",
-        remove_name: typing.Union[bool, typing.Any] = False,
-        remove_active: typing.Union[bool, typing.Any] = False):
+        name: str = "",
+        remove_name: bool = False,
+        remove_active: bool = False):
     ''' Add or remove grease pencil material preset
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     :param name: Name, Name of the preset, used to make the path name
-    :type name: typing.Union[str, typing.Any]
+    :type name: str
     :param remove_name: remove_name
-    :type remove_name: typing.Union[bool, typing.Any]
+    :type remove_name: bool
     :param remove_active: remove_active
-    :type remove_active: typing.Union[bool, typing.Any]
+    :type remove_active: bool
     '''
 
     pass
@@ -417,19 +415,19 @@ def gpencil_material_preset_add(
 def light_cache_bake(override_context: typing.
                      Union[typing.Dict, 'bpy.types.Context'] = None,
                      execution_context: typing.Union[str, int] = None,
-                     undo: typing.Optional[bool] = None,
+                     undo: bool = None,
                      *,
-                     delay: typing.Optional[typing.Any] = 0,
-                     subset: typing.Optional[typing.Any] = 'ALL'):
+                     delay: int = 0,
+                     subset: typing.Union[str, int] = 'ALL'):
     ''' Bake the active view layer lighting
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     :param delay: Delay, Delay in millisecond before baking starts
-    :type delay: typing.Optional[typing.Any]
-    :param subset: Subset, Subset of probes to update * ``ALL`` All Light Probes -- Bake both irradiance grids and reflection cubemaps. * ``DIRTY`` Dirty Only -- Only bake light probes that are marked as dirty. * ``CUBEMAPS`` Cubemaps Only -- Try to only bake reflection cubemaps if irradiance grids are up to date.
-    :type subset: typing.Optional[typing.Any]
+    :type delay: int
+    :param subset: Subset, Subset of probes to update * ALL All Light Probes -- Bake both irradiance grids and reflection cubemaps. * DIRTY Dirty Only -- Only bake light probes that are marked as dirty. * CUBEMAPS Cubemaps Only -- Try to only bake reflection cubemaps if irradiance grids are up to date.
+    :type subset: typing.Union[str, int]
     '''
 
     pass
@@ -438,12 +436,12 @@ def light_cache_bake(override_context: typing.
 def light_cache_free(override_context: typing.
                      Union[typing.Dict, 'bpy.types.Context'] = None,
                      execution_context: typing.Union[str, int] = None,
-                     undo: typing.Optional[bool] = None):
+                     undo: bool = None):
     ''' Delete cached indirect lighting
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     '''
 
     pass
@@ -452,16 +450,16 @@ def light_cache_free(override_context: typing.
 def new(override_context: typing.Union[typing.
                                        Dict, 'bpy.types.Context'] = None,
         execution_context: typing.Union[str, int] = None,
-        undo: typing.Optional[bool] = None,
+        undo: bool = None,
         *,
-        type: typing.Optional[typing.Any] = 'NEW'):
+        type: typing.Union[str, int] = 'NEW'):
     ''' Add new scene by type
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
-    :param type: Type * ``NEW`` New -- Add a new, empty scene with default settings. * ``EMPTY`` Copy Settings -- Add a new, empty scene, and copy settings from the current scene. * ``LINK_COPY`` Linked Copy -- Link in the collections from the current scene (shallow copy). * ``FULL_COPY`` Full Copy -- Make a full copy of the current scene.
-    :type type: typing.Optional[typing.Any]
+    :type undo: bool
+    :param type: Type * NEW New -- Add a new, empty scene with default settings. * EMPTY Copy Settings -- Add a new, empty scene, and copy settings from the current scene. * LINK_COPY Linked Copy -- Link in the collections from the current scene (shallow copy). * FULL_COPY Full Copy -- Make a full copy of the current scene.
+    :type type: typing.Union[str, int]
     '''
 
     pass
@@ -470,16 +468,16 @@ def new(override_context: typing.Union[typing.
 def new_sequencer(override_context: typing.
                   Union[typing.Dict, 'bpy.types.Context'] = None,
                   execution_context: typing.Union[str, int] = None,
-                  undo: typing.Optional[bool] = None,
+                  undo: bool = None,
                   *,
-                  type: typing.Optional[typing.Any] = 'NEW'):
+                  type: typing.Union[str, int] = 'NEW'):
     ''' Add new scene by type in the sequence editor and assign to active strip
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
-    :param type: Type * ``NEW`` New -- Add a new, empty scene with default settings. * ``EMPTY`` Copy Settings -- Add a new, empty scene, and copy settings from the current scene. * ``LINK_COPY`` Linked Copy -- Link in the collections from the current scene (shallow copy). * ``FULL_COPY`` Full Copy -- Make a full copy of the current scene.
-    :type type: typing.Optional[typing.Any]
+    :type undo: bool
+    :param type: Type * NEW New -- Add a new, empty scene with default settings. * EMPTY Copy Settings -- Add a new, empty scene, and copy settings from the current scene. * LINK_COPY Linked Copy -- Link in the collections from the current scene (shallow copy). * FULL_COPY Full Copy -- Make a full copy of the current scene.
+    :type type: typing.Union[str, int]
     '''
 
     pass
@@ -488,12 +486,12 @@ def new_sequencer(override_context: typing.
 def render_view_add(override_context: typing.
                     Union[typing.Dict, 'bpy.types.Context'] = None,
                     execution_context: typing.Union[str, int] = None,
-                    undo: typing.Optional[bool] = None):
+                    undo: bool = None):
     ''' Add a render view
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     '''
 
     pass
@@ -502,12 +500,12 @@ def render_view_add(override_context: typing.
 def render_view_remove(override_context: typing.
                        Union[typing.Dict, 'bpy.types.Context'] = None,
                        execution_context: typing.Union[str, int] = None,
-                       undo: typing.Optional[bool] = None):
+                       undo: bool = None):
     ''' Remove the selected render view
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     '''
 
     pass
@@ -516,16 +514,16 @@ def render_view_remove(override_context: typing.
 def view_layer_add(override_context: typing.
                    Union[typing.Dict, 'bpy.types.Context'] = None,
                    execution_context: typing.Union[str, int] = None,
-                   undo: typing.Optional[bool] = None,
+                   undo: bool = None,
                    *,
-                   type: typing.Optional[typing.Any] = 'NEW'):
+                   type: typing.Union[str, int] = 'NEW'):
     ''' Add a view layer
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
-    :param type: Type * ``NEW`` New -- Add a new view layer. * ``COPY`` Copy Settings -- Copy settings of current view layer. * ``EMPTY`` Blank -- Add a new view layer with all collections disabled.
-    :type type: typing.Optional[typing.Any]
+    :type undo: bool
+    :param type: Type * NEW New -- Add a new view layer. * COPY Copy Settings -- Copy settings of current view layer. * EMPTY Blank -- Add a new view layer with all collections disabled.
+    :type type: typing.Union[str, int]
     '''
 
     pass
@@ -534,12 +532,12 @@ def view_layer_add(override_context: typing.
 def view_layer_add_aov(override_context: typing.
                        Union[typing.Dict, 'bpy.types.Context'] = None,
                        execution_context: typing.Union[str, int] = None,
-                       undo: typing.Optional[bool] = None):
+                       undo: bool = None):
     ''' Add a Shader AOV
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     '''
 
     pass
@@ -548,16 +546,16 @@ def view_layer_add_aov(override_context: typing.
 def view_layer_add_lightgroup(override_context: typing.
                               Union[typing.Dict, 'bpy.types.Context'] = None,
                               execution_context: typing.Union[str, int] = None,
-                              undo: typing.Optional[bool] = None,
+                              undo: bool = None,
                               *,
-                              name: typing.Union[str, typing.Any] = ""):
+                              name: str = ""):
     ''' Add a Light Group
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     :param name: Name, Name of newly created lightgroup
-    :type name: typing.Union[str, typing.Any]
+    :type name: str
     '''
 
     pass
@@ -567,12 +565,12 @@ def view_layer_add_used_lightgroups(
         override_context: typing.Union[typing.
                                        Dict, 'bpy.types.Context'] = None,
         execution_context: typing.Union[str, int] = None,
-        undo: typing.Optional[bool] = None):
+        undo: bool = None):
     ''' Add all used Light Groups
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     '''
 
     pass
@@ -581,12 +579,12 @@ def view_layer_add_used_lightgroups(
 def view_layer_remove(override_context: typing.
                       Union[typing.Dict, 'bpy.types.Context'] = None,
                       execution_context: typing.Union[str, int] = None,
-                      undo: typing.Optional[bool] = None):
+                      undo: bool = None):
     ''' Remove the selected view layer
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     '''
 
     pass
@@ -595,12 +593,12 @@ def view_layer_remove(override_context: typing.
 def view_layer_remove_aov(override_context: typing.
                           Union[typing.Dict, 'bpy.types.Context'] = None,
                           execution_context: typing.Union[str, int] = None,
-                          undo: typing.Optional[bool] = None):
+                          undo: bool = None):
     ''' Remove Active AOV
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     '''
 
     pass
@@ -610,12 +608,12 @@ def view_layer_remove_lightgroup(
         override_context: typing.Union[typing.
                                        Dict, 'bpy.types.Context'] = None,
         execution_context: typing.Union[str, int] = None,
-        undo: typing.Optional[bool] = None):
+        undo: bool = None):
     ''' Remove Active Lightgroup
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     '''
 
     pass
@@ -625,12 +623,12 @@ def view_layer_remove_unused_lightgroups(
         override_context: typing.Union[typing.
                                        Dict, 'bpy.types.Context'] = None,
         execution_context: typing.Union[str, int] = None,
-        undo: typing.Optional[bool] = None):
+        undo: bool = None):
     ''' Remove all unused Light Groups
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
-    :type undo: typing.Optional[bool]
+    :type undo: bool
     '''
 
     pass
