@@ -138,6 +138,24 @@ def change_path(
     pass
 
 
+def change_scene(override_context: typing.
+                 Union[typing.Dict, 'bpy.types.Context'] = None,
+                 execution_context: typing.Union[str, int] = None,
+                 undo: bool = None,
+                 *,
+                 scene: typing.Union[str, int] = ''):
+    ''' Change Scene assigned to Strip
+
+    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
+    :type execution_context: typing.Union[str, int]
+    :type undo: bool
+    :param scene: Scene
+    :type scene: typing.Union[str, int]
+    '''
+
+    pass
+
+
 def copy(override_context: typing.Union[typing.
                                         Dict, 'bpy.types.Context'] = None,
          execution_context: typing.Union[str, int] = None,
@@ -156,7 +174,7 @@ def crossfade_sounds(override_context: typing.
                      Union[typing.Dict, 'bpy.types.Context'] = None,
                      execution_context: typing.Union[str, int] = None,
                      undo: bool = None):
-    ''' Do cross-fading volume animation of two selected sound strips :file: startup/bl_operators/sequencer.py\:27 <https://developer.blender.org/diffusion/B/browse/master/release/scripts/startup/bl_operators/sequencer.py$27> _
+    ''' Do cross-fading volume animation of two selected sound strips :file: startup/bl_operators/sequencer.py\:25 <https://developer.blender.org/diffusion/B/browse/master/release/scripts/startup/bl_operators/sequencer.py$25> _
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
@@ -192,7 +210,7 @@ def deinterlace_selected_movies(
                                        Dict, 'bpy.types.Context'] = None,
         execution_context: typing.Union[str, int] = None,
         undo: bool = None):
-    ''' Deinterlace all selected movie sources :file: startup/bl_operators/sequencer.py\:115 <https://developer.blender.org/diffusion/B/browse/master/release/scripts/startup/bl_operators/sequencer.py$115> _
+    ''' Deinterlace all selected movie sources :file: startup/bl_operators/sequencer.py\:113 <https://developer.blender.org/diffusion/B/browse/master/release/scripts/startup/bl_operators/sequencer.py$113> _
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
@@ -205,12 +223,16 @@ def deinterlace_selected_movies(
 def delete(override_context: typing.Union[typing.
                                           Dict, 'bpy.types.Context'] = None,
            execution_context: typing.Union[str, int] = None,
-           undo: bool = None):
+           undo: bool = None,
+           *,
+           delete_data: bool = False):
     ''' Erase selected strips from the sequencer
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
     :type undo: bool
+    :param delete_data: Delete Data, After removing the Strip, delete the associated data also
+    :type delete_data: bool
     '''
 
     pass
@@ -433,7 +455,7 @@ def fades_clear(override_context: typing.
                 Union[typing.Dict, 'bpy.types.Context'] = None,
                 execution_context: typing.Union[str, int] = None,
                 undo: bool = None):
-    ''' Removes fade animation from selected sequences :file: startup/bl_operators/sequencer.py\:134 <https://developer.blender.org/diffusion/B/browse/master/release/scripts/startup/bl_operators/sequencer.py$134> _
+    ''' Removes fade animation from selected sequences :file: startup/bl_operators/sequencer.py\:132 <https://developer.blender.org/diffusion/B/browse/master/release/scripts/startup/bl_operators/sequencer.py$132> _
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
@@ -745,6 +767,7 @@ def movie_strip_add(
         overlap_shuffle_override: bool = False,
         fit_method: typing.Union[str, int] = 'FIT',
         set_view_transform: bool = True,
+        adjust_playback_rate: bool = True,
         sound: bool = True,
         use_framerate: bool = True):
     ''' Add a movie strip to the sequencer
@@ -818,6 +841,8 @@ def movie_strip_add(
     :type fit_method: typing.Union[str, int]
     :param set_view_transform: Set View Transform, Set appropriate view transform based on media color space
     :type set_view_transform: bool
+    :param adjust_playback_rate: Adjust Playback Rate, Play at normal speed regardless of scene FPS
+    :type adjust_playback_rate: bool
     :param sound: Sound, Load sound with the movie
     :type sound: bool
     :param use_framerate: Use Movie Framerate, Use framerate from the movie to keep sound and video in sync
@@ -1049,6 +1074,39 @@ def scene_strip_add(override_context: typing.
     pass
 
 
+def scene_strip_add_new(override_context: typing.
+                        Union[typing.Dict, 'bpy.types.Context'] = None,
+                        execution_context: typing.Union[str, int] = None,
+                        undo: bool = None,
+                        *,
+                        frame_start: int = 0,
+                        channel: int = 1,
+                        replace_sel: bool = True,
+                        overlap: bool = False,
+                        overlap_shuffle_override: bool = False,
+                        type: typing.Union[str, int] = 'NEW'):
+    ''' Create a new Strip and add a assign a new Scene as source
+
+    :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
+    :type execution_context: typing.Union[str, int]
+    :type undo: bool
+    :param frame_start: Start Frame, Start frame of the sequence strip
+    :type frame_start: int
+    :param channel: Channel, Channel to place this strip into
+    :type channel: int
+    :param replace_sel: Replace Selection, Replace the current selection
+    :type replace_sel: bool
+    :param overlap: Allow Overlap, Don't correct overlap on new sequence strips
+    :type overlap: bool
+    :param overlap_shuffle_override: Override Overlap Shuffle Behavior, Use the overlap_mode tool settings to determine how to shuffle overlapping strips
+    :type overlap_shuffle_override: bool
+    :param type: Type * NEW New -- Add new Strip with a new empty Scene with default settings. * EMPTY Copy Settings -- Add a new Strip, with an empty scene, and copy settings from the current scene. * LINK_COPY Linked Copy -- Add a Strip and link in the collections from the current scene (shallow copy). * FULL_COPY Full Copy -- Add a Strip and make a full copy of the current scene.
+    :type type: typing.Union[str, int]
+    '''
+
+    pass
+
+
 def select(override_context: typing.Union[typing.
                                           Dict, 'bpy.types.Context'] = None,
            execution_context: typing.Union[str, int] = None,
@@ -1518,14 +1576,14 @@ def strip_color_tag_set(override_context: typing.
                         execution_context: typing.Union[str, int] = None,
                         undo: bool = None,
                         *,
-                        color: typing.Union[str, int] = 'NONE'):
+                        color: typing.Union[int, str] = 'NONE'):
     ''' Set a color tag for the selected strips
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
     :type undo: bool
-    :param color: Color Tag * NONE None -- Assign no color tag to the collection. * COLOR_01 Color 01. * COLOR_02 Color 02. * COLOR_03 Color 03. * COLOR_04 Color 04. * COLOR_05 Color 05. * COLOR_06 Color 06. * COLOR_07 Color 07. * COLOR_08 Color 08. * COLOR_09 Color 09.
-    :type color: typing.Union[str, int]
+    :param color: Color Tag
+    :type color: typing.Union[int, str]
     '''
 
     pass
@@ -1557,14 +1615,14 @@ def strip_modifier_add(override_context: typing.
                        execution_context: typing.Union[str, int] = None,
                        undo: bool = None,
                        *,
-                       type: typing.Union[str, int] = 'COLOR_BALANCE'):
+                       type: typing.Union[int, str] = 'COLOR_BALANCE'):
     ''' Add a modifier to the strip
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
     :type undo: bool
     :param type: Type
-    :type type: typing.Union[str, int]
+    :type type: typing.Union[int, str]
     '''
 
     pass
