@@ -7,12 +7,12 @@ GenericType = typing.TypeVar("GenericType")
 
 def abspath(path,
             *,
-            start: typing.Union[bytes, str] = None,
+            start: typing.Union[str, bytes] = None,
             library: 'bpy.types.Library' = None) -> str:
     ''' Returns the absolute path relative to the current blend file using the "//" prefix.
 
     :param start: Relative to this path, when not set the current filename is used.
-    :type start: typing.Union[bytes, str]
+    :type start: typing.Union[str, bytes]
     :param library: The library this path is from. This is only included for convenience, when the library is not None its path replaces *start*.
     :type library: 'bpy.types.Library'
     :rtype: str
@@ -32,11 +32,11 @@ def basename(path) -> str:
     pass
 
 
-def clean_name(name: typing.Union[bytes, str], *, replace: str = '_') -> str:
+def clean_name(name: typing.Union[str, bytes], *, replace: str = '_') -> str:
     ''' Returns a name with characters replaced that may cause problems under various circumstances, such as writing to a file. All characters besides A-Z/a-z, 0-9 are replaced with "_" or the *replace* argument if defined.
 
     :param name: The path name.
-    :type name: typing.Union[bytes, str]
+    :type name: typing.Union[str, bytes]
     :param replace: The replacement for non-valid characters.
     :type replace: str
     :rtype: str
@@ -104,11 +104,11 @@ def ensure_ext(filepath: str, ext: str, *,
     pass
 
 
-def is_subdir(path: typing.Union[bytes, str], directory) -> bool:
+def is_subdir(path: typing.Union[str, bytes], directory) -> bool:
     ''' Returns true if *path* in a subdirectory of *directory*. Both paths must be absolute.
 
     :param path: An absolute path.
-    :type path: typing.Union[bytes, str]
+    :type path: typing.Union[str, bytes]
     :rtype: bool
     :return: Whether or not the path is a subdirectory.
     '''
@@ -154,15 +154,15 @@ def reduce_dirs(dirs: typing.List[str]) -> typing.List[str]:
     pass
 
 
-def relpath(path: typing.Union[bytes, str],
+def relpath(path: typing.Union[str, bytes],
             *,
-            start: typing.Union[bytes, str] = None) -> str:
+            start: typing.Union[str, bytes] = None) -> str:
     ''' Returns the path relative to the current blend file using the "//" prefix.
 
     :param path: An absolute path.
-    :type path: typing.Union[bytes, str]
+    :type path: typing.Union[str, bytes]
     :param start: Relative to this path, when not set the current filename is used.
-    :type start: typing.Union[bytes, str]
+    :type start: typing.Union[str, bytes]
     :rtype: str
     :return: The relative path.
     '''
