@@ -1,7 +1,8 @@
 import sys
 import typing
 import bpy.types
-import bpy.context
+
+GenericType = typing.TypeVar("GenericType")
 
 
 class ExportHelper:
@@ -57,15 +58,16 @@ def axis_conversion_ensure(operator: 'bpy.types.Operator', forward_attr: str,
     pass
 
 
-def create_derived_objects(depsgraph: 'bpy.types.Depsgraph',
-                           objects: typing.List['bpy.types.Object']) -> dict:
+def create_derived_objects(
+        depsgraph: 'bpy.types.Depsgraph',
+        objects: typing.List['bpy.types.Object']) -> typing.Dict:
     ''' This function takes a sequence of objects, returning their instances.
 
     :param depsgraph: The evaluated depsgraph.
     :type depsgraph: 'bpy.types.Depsgraph'
     :param objects: A sequencer of objects.
     :type objects: typing.List['bpy.types.Object']
-    :rtype: dict
+    :rtype: typing.Dict
     :return: A dictionary where each key is an object from objects , values are lists of ( bpy.types.Object , mathutils.Matrix ) tuples representing instances.
     '''
 
@@ -85,7 +87,7 @@ def path_reference(filepath: str,
                    base_dst: str,
                    mode: str = 'AUTO',
                    copy_subdir: str = '',
-                   copy_set: set = None,
+                   copy_set: typing.Set = None,
                    library: 'bpy.types.Library' = None) -> str:
     ''' Return a filepath relative to a destination directory, for use with exporters.
 
@@ -100,7 +102,7 @@ def path_reference(filepath: str,
     :param copy_subdir: the subdirectory of *base_dst* to use when mode='COPY'.
     :type copy_subdir: str
     :param copy_set: collect from/to pairs when mode='COPY', pass to *path_reference_copy* when exporting is done.
-    :type copy_set: set
+    :type copy_set: typing.Set
     :param library: The library this path is relative to.
     :type library: 'bpy.types.Library'
     :rtype: str
@@ -110,31 +112,31 @@ def path_reference(filepath: str,
     pass
 
 
-def path_reference_copy(copy_set: set, report='<built-in function print>'):
+def path_reference_copy(copy_set: typing.Set,
+                        report='<built-in function print>'):
     ''' Execute copying files of path_reference
 
     :param copy_set: set of (from, to) pairs to copy.
-    :type copy_set: set
+    :type copy_set: typing.Set
     :param report: function used for reporting warnings, takes a string argument.
     '''
 
     pass
 
 
-def unique_name(key: 'bpy.context.object',
+def unique_name(key,
                 name: str,
-                name_dict: dict,
+                name_dict: typing.Dict,
                 name_max=-1,
                 clean_func=None,
                 sep: str = '.'):
     ''' Helper function for storing unique names which may have special characters stripped and restricted to a maximum length.
 
     :param key: unique item this name belongs to, name_dict[key] will be reused when available. This can be the object, mesh, material, etc instance itself.
-    :type key: 'bpy.context.object'
     :param name: The name used to create a unique value in *name_dict*.
     :type name: str
     :param name_dict: This is used to cache namespace to ensure no collisions occur, this should be an empty dict initially and only modified by this function.
-    :type name_dict: dict
+    :type name_dict: typing.Dict
     :param clean_func: Function to call on *name* before creating a unique value.
     :param sep: Separator to use when between the name and a number when a duplicate name is found.
     :type sep: str
