@@ -10,7 +10,7 @@ GenericType = typing.TypeVar("GenericType")
 class BVHTree:
     @classmethod
     def FromBMesh(cls, bmesh: 'bmesh.types.BMesh', epsilon: float = 0.0):
-        ''' BVH tree based on `BMesh` data.
+        ''' BVH tree based on BMesh data.
 
         :param bmesh: BMesh data.
         :type bmesh: 'bmesh.types.BMesh'
@@ -27,7 +27,7 @@ class BVHTree:
                    render=False,
                    cage: bool = False,
                    epsilon: float = 0.0):
-        ''' BVH tree based on `Object` data.
+        ''' BVH tree based on Object data.
 
         :param object: Object data.
         :type object: 'bpy.types.Object'
@@ -50,7 +50,7 @@ class BVHTree:
                      epsilon: float = 0.0):
         ''' BVH tree constructed geometry passed in as arguments.
 
-        :param vertices: float triplets each representing ``(x, y, z)``
+        :param vertices: float triplets each representing (x, y, z)
         :type vertices: typing.List[float]
         :param polygons: Sequence of polyugons, each containing indices to the vertices argument.
         :type polygons: 'bpy.types.Sequence'
@@ -66,11 +66,11 @@ class BVHTree:
         ''' Find the nearest element (typically face index) to a point.
 
         :param co: Find nearest element to this point.
-        :type co: typing.Union[typing.Sequence[float], 'mathutils.Vector']
+        :type co: 'mathutils.Vector'
         :param distance: Maximum distance threshold.
         :type distance: float
         :rtype: typing.Tuple
-        :return: Returns a tuple (`Vector` location, `Vector` normal, int index, float distance), Values will all be None if no hit is found.
+        :return: Returns a tuple ( Vector location, Vector normal, int index, float distance), Values will all be None if no hit is found.
         '''
         pass
 
@@ -79,11 +79,11 @@ class BVHTree:
         ''' Find the nearest elements (typically face index) to a point in the distance range.
 
         :param co: Find nearest elements to this point.
-        :type co: typing.Union[typing.Sequence[float], 'mathutils.Vector']
+        :type co: 'mathutils.Vector'
         :param distance: Maximum distance threshold.
         :type distance: float
         :rtype: typing.List
-        :return: Returns a list of tuples (`Vector` location, `Vector` normal, int index, float distance),
+        :return: Returns a list of tuples ( Vector location, Vector normal, int index, float distance),
         '''
         pass
 
@@ -98,26 +98,24 @@ class BVHTree:
         pass
 
     def ray_cast(self,
-                 origin,
-                 direction: typing.Union[typing.
-                                         Sequence[float], 'mathutils.Vector'],
+                 origin: 'mathutils.Vector',
+                 direction: 'mathutils.Vector',
                  distance: float = 'sys.float_info.max') -> typing.Tuple:
         ''' Cast a ray onto the mesh.
 
-        :param co: Start location of the ray in object space.
-        :type co: typing.Union[typing.Sequence[float], 'mathutils.Vector']
+        :param origin: Start location of the ray in object space.
+        :type origin: 'mathutils.Vector'
         :param direction: Direction of the ray in object space.
-        :type direction: typing.Union[typing.Sequence[float], 'mathutils.Vector']
+        :type direction: 'mathutils.Vector'
         :param distance: Maximum distance threshold.
         :type distance: float
         :rtype: typing.Tuple
-        :return: Returns a tuple (`Vector` location, `Vector` normal, int index, float distance), Values will all be None if no hit is found.
+        :return: Returns a tuple ( Vector location, Vector normal, int index, float distance), Values will all be None if no hit is found.
         '''
         pass
 
-    def __init__(self, size) -> typing.Any:
+    def __init__(self, size):
         ''' 
 
-        :rtype: typing.Any
         '''
         pass
