@@ -85,6 +85,14 @@ def geometry_input_node_items(context):
     pass
 
 
+def geometry_instance_node_items(context):
+    ''' 
+
+    '''
+
+    pass
+
+
 def geometry_material_node_items(context):
     ''' 
 
@@ -197,6 +205,14 @@ def unregister():
     pass
 
 
+def uv_node_items(context):
+    ''' 
+
+    '''
+
+    pass
+
+
 def world_shader_nodes_poll(context):
     ''' 
 
