@@ -1,6 +1,8 @@
 import sys
 import typing
 
+GenericType = typing.TypeVar("GenericType")
+
 
 class InfoFunctionRNA:
     args = None
@@ -94,6 +96,9 @@ class InfoPropertyRNA:
     enum_items = None
     ''' '''
 
+    enum_pointer = None
+    ''' '''
+
     fixed_type = None
     ''' '''
 
@@ -145,7 +150,8 @@ class InfoPropertyRNA:
         '''
         pass
 
-    def get_type_description(self, as_ret, as_arg, class_fmt, collection_id):
+    def get_type_description(self, as_ret, as_arg, class_fmt, collection_id,
+                             enum_descr_override):
         ''' 
 
         '''
@@ -219,6 +225,12 @@ class InfoStructRNA:
         '''
         pass
 
+    def get_py_c_properties_getset(self):
+        ''' 
+
+        '''
+        pass
+
     def get_py_functions(self):
         ''' 
 
